@@ -1,120 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "File could not be found" : "File could not be found",
-    "Move or copy" : "Move or copy",
-    "Download" : "Download",
-    "Delete" : "Delete",
-    "Tags" : "Tags",
-    "Show list view" : "Show list view",
-    "Show grid view" : "Show grid view",
-    "Home" : "Home",
-    "Close" : "Close",
-    "Could not create folder \"{dir}\"" : "Could not create folder \"{dir}\"",
-    "This will stop your current uploads." : "This will stop your current uploads.",
-    "Upload cancelled." : "Upload cancelled.",
-    "Processing files …" : "Processing files …",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Unable to upload {filename} as it is a directory or has 0 bytes",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Not enough free space, you are uploading {size1} but only {size2} is left",
-    "Target folder \"{dir}\" does not exist any more" : "Target folder \"{dir}\" does not exist any more",
-    "Not enough free space" : "Not enough free space",
-    "An unknown error has occurred" : "An unknown error has occurred",
-    "File could not be uploaded" : "File could not be uploaded",
-    "Uploading …" : "Uploading …",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Uploading … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} of {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Uploading that item is not supported",
-    "Target folder does not exist any more" : "Target folder does not exist any more",
-    "Operation is blocked by access control" : "Operation is blocked by access control",
-    "Error when assembling chunks, status code {status}" : "Error when assembling chunks, status code {status}",
-    "Actions" : "Actions",
-    "Rename" : "Rename",
-    "Move" : "Move",
-    "Copy" : "Copy",
-    "Choose target folder" : "Choose target folder",
-    "Set reminder" : "Set reminder",
-    "Edit locally" : "Edit locally",
-    "Open" : "Open",
-    "Delete file" : "Delete file",
-    "Delete folder" : "Delete folder",
-    "Disconnect storage" : "Disconnect storage",
-    "Leave this share" : "Leave this share",
-    "Could not load info for file \"{file}\"" : "Could not load info for file \"{file}\"",
-    "Files" : "Files",
-    "Details" : "Details",
-    "Please select tag(s) to add to the selection" : "Please select tag(s) to add to the selection",
-    "Apply tag(s) to selection" : "Apply tag(s) to selection",
-    "Select directory \"{dirName}\"" : "Select directory \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Select file \"{fileName}\"",
-    "Pending" : "Pending",
-    "Unable to determine date" : "Unable to determine date",
-    "This operation is forbidden" : "This operation is forbidden",
-    "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
-    "Storage is temporarily not available" : "Storage is temporarily not available",
-    "Could not move \"{file}\", target exists" : "Could not move \"{file}\", target exists",
-    "Could not move \"{file}\"" : "Could not move \"{file}\"",
-    "copy" : "copy",
-    "Could not copy \"{file}\", target exists" : "Could not copy \"{file}\", target exists",
-    "Could not copy \"{file}\"" : "Could not copy \"{file}\"",
-    "Copied {origin} inside {destination}" : "Copied {origin} inside {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copied {origin} and {nbfiles} other files inside {destination}",
-    "Failed to redirect to client" : "Failed to redirect to client",
-    "{newName} already exists" : "{newName} already exists",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Could not rename \"{fileName}\", it does not exist any more",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name.",
-    "Could not rename \"{fileName}\"" : "Could not rename \"{fileName}\"",
-    "Could not create file \"{file}\"" : "Could not create file \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Could not create file \"{file}\" because it already exists",
-    "Could not create folder \"{dir}\" because it already exists" : "Could not create folder \"{dir}\" because it already exists",
-    "Could not fetch file details \"{file}\"" : "Could not fetch file details \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Error deleting file \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "No search results in other folders for {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Enter more than two characters to search in other folders",
-    "Name" : "Name",
-    "Size" : "Size",
-    "Modified" : "Modified",
-    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
-    "_%n file_::_%n files_" : ["%n file","%n files"],
-    "{dirs} and {files}" : "{dirs} and {files}",
-    "_including %n hidden_::_including %n hidden_" : ["including %n hidden","including %n hidden"],
-    "You do not have permission to upload or create files here" : "You do not have permission to upload or create files here",
-    "_Uploading %n file_::_Uploading %n files_" : ["Uploading %n file","Uploading %n files"],
-    "New" : "New",
-    "New file/folder menu" : "New file/folder menu",
-    "Select file range" : "Select file range",
-    "{used}%" : "{used}%",
-    "{used} of {quota} used" : "{used} of {quota} used",
-    "{used} used" : "{used} used",
-    "\"{name}\" is an invalid file name." : "\"{name}\" is an invalid file name.",
-    "File name cannot be empty." : "File name cannot be empty.",
-    "\"/\" is not allowed inside a file name." : "\"/\" is not allowed inside a file name.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" is not an allowed filetype",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Storage of {owner} is full, files cannot be updated or synced anymore!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Your storage is full, files cannot be updated or synced anymore!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Storage of {owner} is almost full ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Your storage is almost full ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["matches \"{filter}\"","match \"{filter}\""],
-    "View in folder" : "View in folder",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Direct link was copied (only works for users who have access to this file/folder)",
-    "Path" : "Path",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
-    "Favorited" : "Favourited",
-    "Favorite" : "Favourite",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copy direct link (only works for users who have access to this file/folder)",
-    "New folder" : "New folder",
-    "Create new folder" : "Create new folder",
-    "Upload file" : "Upload file",
-    "Recent" : "Recent",
-    "Not favorited" : "Not favourited",
-    "Remove from favorites" : "Remove from favourites",
-    "Add to favorites" : "Add to favourites",
-    "An error occurred while trying to update the tags" : "An error occurred whilst trying to update the tags",
     "Added to favorites" : "Added to favourites",
     "Removed from favorites" : "Removed from favourites",
     "You added {file} to your favorites" : "You added {file} to your favourites",
@@ -127,7 +13,7 @@ OC.L10N.register(
     "Restored by {user}" : "Restored by {user}",
     "Renamed by {user}" : "Renamed by {user}",
     "Moved by {user}" : "Moved by {user}",
-    "\"remote user\"" : "\"remote user\"",
+    "\"remote account\"" : "\"remote account\"",
     "You created {file}" : "You created {file}",
     "You created an encrypted file in {file}" : "You created an encrypted file in {file}",
     "{user} created {file}" : "{user} created {file}",
@@ -154,13 +40,19 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "You moved {oldfile} to {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} moved {oldfile} to {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "A file has been added to or removed from your <strong>favourites</strong>",
+    "Files" : "Files",
     "A file or folder has been <strong>changed</strong>" : "A file or folder has been <strong>changed</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "A favourite file or folder has been <strong>changed</strong>",
+    "Failed to authorize" : "Failed to authorize",
+    "Invalid folder path" : "Invalid folder path",
+    "Folder not found" : "Folder not found",
     "Upload (max. %s)" : "Upload (max. %s)",
     "Accept" : "Accept",
     "Reject" : "Reject",
     "Incoming ownership transfer from {user}" : "Incoming ownership transfer from {user}",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour.",
+    "Ownership transfer denied" : "Ownership transfer denied",
+    "Your ownership transfer of {path} was denied by {user}." : "Your ownership transfer of {path} was denied by {user}.",
     "Ownership transfer failed" : "Ownership transfer failed",
     "Your ownership transfer of {path} to {user} failed." : "Your ownership transfer of {path} to {user} failed.",
     "The ownership transfer of {path} from {user} failed." : "The ownership transfer of {path} from {user} failed.",
@@ -168,47 +60,67 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "Your ownership transfer of {path} to {user} has completed.",
     "The ownership transfer of {path} from {user} has completed." : "The ownership transfer of {path} from {user} has completed.",
     "in %s" : "in %s",
+    "Transferred from %1$s on %2$s" : "Transferred from %1$s on %2$s",
+    "Files compatibility" : "Files compatibility",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed.",
+    "Enforce Windows compatibility" : "Enforce Windows compatibility",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity.",
     "File Management" : "File Management",
     "Current directory path" : "Current directory path",
+    "Home" : "Home",
+    "Target folder does not exist any more" : "Target folder does not exist any more",
     "Reload current directory" : "Reload current directory",
     "Go to the \"{dir}\" directory" : "Go to the \"{dir}\" directory",
     "Drag and drop files here to upload" : "Drag and drop files here to upload",
     "Your have used your space quota and cannot upload files anymore" : "Your have used your space quota and cannot upload files anymore",
     "You don’t have permission to upload or create files here" : "You don’t have permission to upload or create files here",
-    "Upload successful" : "Upload successful",
+    "Favorite" : "Favourite",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" action executed successfully",
     "\"{displayName}\" action failed" : "\"{displayName}\" action failed",
     "Toggle selection for file \"{displayName}\"" : "Toggle selection for file \"{displayName}\"",
     "Toggle selection for folder \"{displayName}\"" : "Toggle selection for folder \"{displayName}\"",
+    "File is loading" : "File is loading",
+    "Folder is loading" : "Folder is loading",
     "Rename file" : "Rename file",
-    "File name" : "File name",
+    "Filename" : "Filename",
     "Folder name" : "Folder name",
     "This node is unavailable" : "This node is unavailable",
-    "Download file {name}" : "Download file {name}",
-    "\"{name}\" is not an allowed filetype." : "\"{name}\" is not an allowed filetype.",
-    "{newName} already exists." : "{newName} already exists.",
-    "\"{char}\" is not allowed inside a file name." : "\"{char}\" is not allowed inside a file name.",
-    "Name cannot be empty" : "Name cannot be empty",
-    "Another entry with the same name already exists" : "Another entry with the same name already exists",
+    "Another entry with the same name already exists." : "Another entry with the same name already exists.",
+    "Invalid filename." : "Invalid filename.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Renamed \"{oldName}\" to \"{newName}\"",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Could not rename \"{oldName}\", it does not exist any more",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name.",
-    "Could not rename \"{oldName}\"" : "Could not rename \"{oldName}\"",
-    "Could not copy {file}. {message}" : "Could not copy {file}. {message}",
-    "Could not move {file}. {message}" : "Could not move {file}. {message}",
+    "Pending" : "Pending",
+    "Clear filter" : "Clear filter",
+    "Modified" : "Modified",
+    "Type" : "Type",
+    "Active filters" : "Active filters",
+    "Remove filter" : "Remove filter",
     "Total rows summary" : "Total rows summary",
+    "Name" : "Name",
+    "Size" : "Size",
     "Toggle selection for all files and folders" : "Toggle selection for all files and folders",
+    "Actions" : "Actions",
+    "(selected)" : "(selected)",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" failed on some elements ",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batch action executed successfully",
+    "{count} selected" : "{count} selected",
     "List of files and folders." : "List of files and folders.",
     "Column headers with buttons are sortable." : "Column headers with buttons are sortable.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list.",
     "File not found" : "File not found",
-    "Storage informations" : "Storage informations",
+    "Storage information" : "Storage information",
+    "Storage quota" : "Storage quota",
     "{usedQuotaByte} used" : "{usedQuotaByte} used",
+    "{used} of {quota} used" : "{used} of {quota} used",
     "{relative}% used" : "{relative}% used",
     "Could not refresh storage stats" : "Could not refresh storage stats",
     "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
+    "Create" : "Create",
+    "New folder" : "New folder",
+    "Create new folder" : "Create new folder",
+    "This name is already in use." : "This name is already in use.",
+    "Fill template fields" : "Fill template fields",
+    "Submitting fields…" : "Submitting fields…",
+    "Submit" : "Submit",
     "Transfer ownership of a file or folder" : "Transfer ownership of a file or folder",
     "Choose file or folder to transfer" : "Choose file or folder to transfer",
     "Change" : "Change",
@@ -221,30 +133,37 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Ownership transfer request sent",
     "Cannot transfer ownership of a file or folder you do not own" : "Cannot transfer ownership of a file or folder you do not own",
     "Select file or folder to link to" : "Select file or folder to link to",
-    "Choose file" : "Choose file",
     "Choose {file}" : "Choose {file}",
-    "Add" : "Add",
+    "New" : "New",
     "Loading current folder" : "Loading current folder",
+    "Retry" : "Retry",
     "No files in here" : "No files in here",
     "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
-    "Go to the previous folder" : "Go to the previous folder",
     "Go back" : "Go back",
     "Share" : "Share",
     "Shared by link" : "Shared by link",
     "Shared" : "Shared",
     "Switch to list view" : "Switch to list view",
     "Switch to grid view" : "Switch to grid view",
+    "Upload was cancelled by user" : "Upload was cancelled by user",
+    "Not enough free space" : "Not enough free space",
+    "Operation is blocked by access control" : "Operation is blocked by access control",
     "Error during upload: {message}" : "Error during upload: {message}",
     "Error during upload, status code {status}" : "Error during upload, status code {status}",
     "Unknown error during upload" : "Unknown error during upload",
-    "Open the files app settings" : "Open the files app settings",
+    "Filter filenames…" : "Filter filenames…",
+    "Views" : "Views",
     "Files settings" : "Files settings",
     "File cannot be accessed" : "File cannot be accessed",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "The file could not be found or you do not have permissions to view it. Ask the sender to share it.",
+    "Your files" : "Your files",
+    "Open in files" : "Open in files",
     "Sort favorites first" : "Sort favourites first",
     "Sort folders before files" : "Sort folders before files",
     "Show hidden files" : "Show hidden files",
     "Crop image previews" : "Crop image previews",
     "Enable the grid view" : "Enable the grid view",
+    "Enable folder tree" : "Enable folder tree",
     "Additional settings" : "Additional settings",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URL",
@@ -253,80 +172,236 @@ OC.L10N.register(
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "If you have enabled 2FA, you must create and use a new app password by clicking here.",
     "Clipboard is not available" : "Clipboard is not available",
     "WebDAV URL copied to clipboard" : "WebDAV URL copied to clipboard",
+    "Owner" : "Owner",
+    "Remove from favorites" : "Remove from favourites",
+    "Add to favorites" : "Add to favourites",
+    "Tags" : "Tags",
+    "You" : "You",
+    "Shared multiple times with different people" : "Shared multiple times with different people",
     "Unable to change the favourite state of the file" : "Unable to change the favourite state of the file",
     "Error while loading the file data" : "Error while loading the file data",
     "Pick a template for {name}" : "Pick a template for {name}",
-    "Create" : "Create",
     "Create a new file with the selected template" : "Create a new file with the selected template",
     "Creating file" : "Creating file",
     "Blank" : "Blank",
     "Unable to create new file from template" : "Unable to create new file from template",
+    "Deletion cancelled" : "Deletion cancelled",
     "Delete permanently" : "Delete permanently",
-    "Destination is not a folder" : "Destination is not a folder",
-    "This file/folder is already in that directory" : "This file/folder is already in that directory",
+    "Delete and unshare" : "Delete and unshare",
+    "Leave this share" : "Leave this share",
+    "Leave these shares" : "Leave these shares",
+    "Disconnect storage" : "Disconnect storage",
+    "Disconnect storages" : "Disconnect storages",
+    "Delete file" : "Delete file",
+    "Delete files" : "Delete files",
+    "Delete folder" : "Delete folder",
+    "Delete folders" : "Delete folders",
+    "Delete" : "Delete",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["You are about to permanently delete {count} item","You are about to permanently delete {count} items"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["You are about to delete {count} item","You are about to delete {count} items"],
+    "Confirm deletion" : "Confirm deletion",
+    "Cancel" : "Cancel",
+    "Edit file locally" : "Edit file locally",
+    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system.",
+    "Retry local edit" : "Retry local edit",
+    "Edit online" : "Edit online",
+    "Failed to redirect to client" : "Failed to redirect to client",
+    "Edit locally" : "Edit locally",
+    "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "You cannot move a file/folder onto itself or into a subfolder of itself",
     "(copy)" : "(copy)",
     "(copy %n)" : "(copy %n)",
+    "Move cancelled" : "Move cancelled",
     "A file or folder with that name already exists in this folder" : "A file or folder with that name already exists in this folder",
-    "The files is locked" : "The files is locked",
+    "The files are locked" : "The files are locked",
     "The file does not exist anymore" : "The file does not exist anymore",
     "Choose destination" : "Choose destination",
     "Copy to {target}" : "Copy to {target}",
+    "Copy" : "Copy",
     "Move to {target}" : "Move to {target}",
-    "Cancelled move or copy operation" : "Cancelled move or copy operation",
+    "Move" : "Move",
     "Move or copy operation failed" : "Move or copy operation failed",
+    "Move or copy" : "Move or copy",
+    "Cancelled move or copy of \"{filename}\"." : "Cancelled move or copy of \"{filename}\".",
+    "Cancelled move or copy operation" : "Cancelled move or copy operation",
     "Open folder {displayName}" : "Open folder {displayName}",
     "Open in Files" : "Open in Files",
+    "Rename" : "Rename",
     "Open details" : "Open details",
-    "Create new templates folder" : "Create new templates folder",
-    "Templates" : "Templates",
-    "Unable to initialize the templates directory" : "Unable to initialize the templates directory",
+    "View in folder" : "View in folder",
+    "Today" : "Today",
+    "Last 7 days" : "Last 7 days",
+    "Last 30 days" : "Last 30 days",
+    "This year ({year})" : "This year ({year})",
+    "Last year ({year})" : "Last year ({year})",
+    "Documents" : "Documents",
+    "Spreadsheets" : "Spreadsheets",
+    "Presentations" : "Presentations",
+    "PDFs" : "PDFs",
+    "Folders" : "Folders",
+    "Audio" : "Audio",
+    "Photos and images" : "Photos and images",
+    "Videos" : "Videos",
+    "New folder creation cancelled" : "New folder creation cancelled",
     "Created new folder \"{name}\"" : "Created new folder \"{name}\"",
+    "Unable to initialize the templates directory" : "Unable to initialize the templates directory",
+    "Create templates folder" : "Create templates folder",
+    "Templates" : "Templates",
+    "New template folder" : "New template folder",
+    "In folder" : "In folder",
+    "Search in folder: {folder}" : "Search in folder: {folder}",
     "One of the dropped files could not be processed" : "One of the dropped files could not be processed",
-    "Uploading \"{filename}\" failed" : "Uploading \"{filename}\" failed",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Your browser does not support the Filesystem API. Directories will not be uploaded",
+    "No files to upload" : "No files to upload",
+    "Unable to create the directory {directory}" : "Unable to create the directory {directory}",
+    "Some files could not be uploaded" : "Some files could not be uploaded",
+    "Files uploaded successfully" : "Files uploaded successfully",
+    "No files to process" : "No files to process",
+    "Some files could not be copied" : "Some files could not be copied",
+    "Some files could not be moved" : "Some files could not be moved",
+    "Files copied successfully" : "Files copied successfully",
+    "Files moved successfully" : "Files moved successfully",
+    "Conflicts resolution skipped" : "Conflicts resolution skipped",
+    "Upload cancelled" : "Upload cancelled",
+    "This operation is forbidden" : "This operation is forbidden",
+    "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
+    "Storage is temporarily not available" : "Storage is temporarily not available",
+    "Unexpected error: {error}" : "Unexpected error: {error}",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} folder","{folderCount} folders"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} file","{fileCount} files"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 file and {folderCount} folder","1 file and {folderCount} folders"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} file and 1 folder","{fileCount} files and 1 folder"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} files and {folderCount} folders",
-    "List of favorites files and folders." : "List of favourites files and folders.",
+    "Filename must not be empty." : "Filename must not be empty.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" is not allowed inside a filename.",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" is a reserved name and not allowed for filenames.",
+    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" is not an allowed filetype.",
+    "Filenames must not end with \"{extension}\"." : "Filenames must not end with \"{extension}\".",
+    "List of favorite files and folders." : "List of favourite files and folders.",
     "No favorites yet" : "No favourites yet",
     "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favourite will show up here",
     "All files" : "All files",
     "List of your files and folders." : "List of your files and folders.",
+    "All folders" : "All folders",
+    "Personal Files" : "Personal Files",
+    "List of your files and folders that are not shared." : "List of your files and folders that are not shared.",
+    "No personal files found" : "No personal files found",
+    "Files that are not shared will show up here." : "Files that are not shared will show up here.",
+    "Recent" : "Recent",
     "List of recently modified files and folders." : "List of recently modified files and folders.",
     "No recently modified files" : "No recently modified files",
     "Files and folders you recently modified will show up here." : "Files and folders you recently modified will show up here.",
+    "You do not have permission to upload or create files here" : "You do not have permission to upload or create files here",
     "No entries found in this folder" : "No entries found in this folder",
     "Select all" : "Select all",
     "Upload too large" : "Upload too large",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
+    "File could not be found" : "File could not be found",
+    "Download" : "Download",
+    "Show list view" : "Show list view",
+    "Show grid view" : "Show grid view",
+    "Close" : "Close",
+    "Could not create folder \"{dir}\"" : "Could not create folder \"{dir}\"",
+    "This will stop your current uploads." : "This will stop your current uploads.",
+    "Upload cancelled." : "Upload cancelled.",
+    "Processing files …" : "Processing files …",
+    "…" : "…",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Unable to upload {filename} as it is a directory or has 0 bytes",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Not enough free space, you are uploading {size1} but only {size2} is left",
+    "Target folder \"{dir}\" does not exist any more" : "Target folder \"{dir}\" does not exist any more",
+    "An unknown error has occurred" : "An unknown error has occurred",
+    "File could not be uploaded" : "File could not be uploaded",
+    "Uploading …" : "Uploading …",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Uploading … ({currentNumber}/{total})",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} of {totalSize} ({bitrate})",
+    "Uploading that item is not supported" : "Uploading that item is not supported",
+    "Error when assembling chunks, status code {status}" : "Error when assembling chunks, status code {status}",
+    "Choose target folder" : "Choose target folder",
+    "Set reminder" : "Set reminder",
+    "Open" : "Open",
+    "Could not load info for file \"{file}\"" : "Could not load info for file \"{file}\"",
+    "Details" : "Details",
+    "Please select tag(s) to add to the selection" : "Please select tag(s) to add to the selection",
+    "Apply tag(s) to selection" : "Apply tag(s) to selection",
+    "Select directory \"{dirName}\"" : "Select directory \"{dirName}\"",
+    "Select file \"{fileName}\"" : "Select file \"{fileName}\"",
+    "Unable to determine date" : "Unable to determine date",
+    "Could not move \"{file}\", target exists" : "Could not move \"{file}\", target exists",
+    "Could not move \"{file}\"" : "Could not move \"{file}\"",
+    "copy" : "copy",
+    "Could not copy \"{file}\", target exists" : "Could not copy \"{file}\", target exists",
+    "Could not copy \"{file}\"" : "Could not copy \"{file}\"",
+    "Copied {origin} inside {destination}" : "Copied {origin} inside {destination}",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copied {origin} and {nbfiles} other files inside {destination}",
+    "{newName} already exists" : "{newName} already exists",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Could not rename \"{fileName}\", it does not exist any more",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name.",
+    "Could not rename \"{fileName}\"" : "Could not rename \"{fileName}\"",
+    "Could not create file \"{file}\"" : "Could not create file \"{file}\"",
+    "Could not create file \"{file}\" because it already exists" : "Could not create file \"{file}\" because it already exists",
+    "Could not create folder \"{dir}\" because it already exists" : "Could not create folder \"{dir}\" because it already exists",
+    "Could not fetch file details \"{file}\"" : "Could not fetch file details \"{file}\"",
+    "Error deleting file \"{fileName}\"." : "Error deleting file \"{fileName}\".",
+    "No search results in other folders for {tag}{filter}{endtag}" : "No search results in other folders for {tag}{filter}{endtag}",
+    "Enter more than two characters to search in other folders" : "Enter more than two characters to search in other folders",
+    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
+    "_%n file_::_%n files_" : ["%n file","%n files"],
+    "{dirs} and {files}" : "{dirs} and {files}",
+    "_including %n hidden_::_including %n hidden_" : ["including %n hidden","including %n hidden"],
+    "_Uploading %n file_::_Uploading %n files_" : ["Uploading %n file","Uploading %n files"],
+    "New file/folder menu" : "New file/folder menu",
+    "Select file range" : "Select file range",
+    "{used}%" : "{used}%",
+    "{used} used" : "{used} used",
+    "\"{name}\" is an invalid file name." : "\"{name}\" is an invalid file name.",
+    "File name cannot be empty." : "File name cannot be empty.",
+    "\"/\" is not allowed inside a file name." : "\"/\" is not allowed inside a file name.",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" is not an allowed filetype",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Storage of {owner} is full, files cannot be updated or synced anymore!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Your storage is full, files cannot be updated or synced anymore!",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Storage of {owner} is almost full ({usedSpacePercent}%).",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%).",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%).",
+    "Your storage is almost full ({usedSpacePercent}%)." : "Your storage is almost full ({usedSpacePercent}%).",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["matches \"{filter}\"","match \"{filter}\""],
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Direct link was copied (only works for users who have access to this file/folder)",
+    "Path" : "Path",
+    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
+    "Favorited" : "Added to Favourites",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copy direct link (only works for users who have access to this file/folder)",
+    "Upload file" : "Upload file",
+    "Not favorited" : "Not favourited",
+    "An error occurred while trying to update the tags" : "An error occurred whilst trying to update the tags",
+    "\"remote user\"" : "\"remote user\"",
+    "{newName} already exists." : "{newName} already exists.",
+    "\"{segment}\" is not allowed inside a filename." : "\"{segment}\" is not allowed inside a filename.",
+    "\"{segment}\" is a forbidden file or folder name." : "\"{segment}\" is a forbidden file or folder name.",
+    "\"{segment}\" is not an allowed filetype." : "\"{segment}\" is not an allowed filetype.",
+    "Filenames must not end with \"{segment}\"." : "Filenames must not end with \"{segment}\".",
+    "Name cannot be empty" : "Name cannot be empty",
+    "Another entry with the same name already exists" : "Another entry with the same name already exists",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Could not rename \"{oldName}\", it does not exist any more",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name.",
+    "Could not rename \"{oldName}\"" : "Could not rename \"{oldName}\"",
+    "Storage informations" : "Storage informations",
+    "Choose file" : "Choose file",
+    "Go to the previous folder" : "Go to the previous folder",
+    "Open the files app settings" : "Open the files app settings",
+    "You might not have have permissions to view it, ask the sender to share it" : "You might not have have permissions to view it, ask the sender to share it",
+    "The files is locked" : "The files is locked",
+    "Create new templates folder" : "Create new templates folder",
+    "List of favorites files and folders." : "List of favourite files and folders.",
+    "Toggle %1$s sublist" : "Toggle %1$s sublist",
     "Text file" : "Text file",
     "New text file.txt" : "New text file.txt",
-    "You can only favorite a single file or folder at a time" : "You can only favourite a single file or folder at a time",
-    "Search users" : "Search users",
-    "You might not have have permissions to view it, ask the sender to share it" : "You might not have have permissions to view it, ask the sender to share it",
-    "Cancel" : "Cancel",
-    "Set up templates folder" : "Set up templates folder",
-    "Toggle %1$s sublist" : "Toggle %1$s sublist",
-    "Toggle grid view" : "Toggle grid view",
-    "Deleted files" : "Deleted files",
-    "Shares" : "Shares",
-    "Shared with others" : "Shared with others",
-    "Shared with you" : "Shared with you",
-    "Deleted shares" : "Deleted shares",
-    "Pending shares" : "Pending shares",
-    "This file has the tag {tag}" : "This file has the tag {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "This file has the tags {firstTags} and {lastTag}",
-    "Select the row for {displayName}" : "Select the row for {displayName}",
-    "Open folder {name}" : "Open folder {name}",
-    "Unselect all" : "Unselect all",
-    "ascending" : "ascending",
-    "descending" : "descending",
-    "Sort list by {column} ({direction})" : "Sort list by {column} ({direction})",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list.",
-    "Search for an account" : "Search for an account",
-    "Choose" : "Choose",
-    "No files or folders have been deleted yet" : "No files or folders have been deleted yet"
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Direct link was copied (only works for people who have access to this file/folder)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Copy direct link (only works for people who have access to this file/folder)",
+    "Favored" : "Favoured",
+    "Favor" : "Favour",
+    "Not favored" : "Not favoured"
 },
 "nplurals=2; plural=(n != 1);");
