@@ -65,6 +65,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Jeigu gavote šį laišką, tuomet atrodo, jog el. pašto konfigūracija yra teisinga.",
     "Email could not be sent. Check your mail server log" : "El. laiškas nebuvo išsiųstas. Peržiūrėkite savo pašto serverio žurnalą.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Siunčiant el. laišką atsirado problemų. Peržiūrėkite savo nustatymus. (Klaida: %s)",
+    "Disabled accounts" : "Išjungtos paskyros",
     "Invalid account" : "Neteisinga paskyra",
     "Invalid mail address" : "Neteisingas pašto adresas",
     "Settings saved" : "Nustatymai įrašyti",
@@ -89,6 +90,7 @@ OC.L10N.register(
     "Welcome aboard" : "Sveikiname prisijungus",
     "Welcome aboard %s" : "%s, sveikiname prisijungus",
     "Welcome to your %s account, you can add, protect, and share your data." : "Turėdami %s paskyrą duomenis galite pridėti, apsaugoti ir jais pasidalinti.",
+    "Your Login is: %s" : "Jūsų prisijungimas yra: %s",
     "Set your password" : "Nustatykite savo slaptažodį.",
     "Go to %s" : "Pereiti į %s",
     "Install Client" : "Įdiegti kliento programą",
@@ -97,6 +99,7 @@ OC.L10N.register(
     "Administration" : "Administravimas",
     "Users" : "Naudotojai",
     "Additional settings" : "Papildomi nustatymai",
+    "Artificial Intelligence" : "Dirbtinis intelektas",
     "Administration privileges" : "Administravimo teisės",
     "Groupware" : "Grupinio darbo įranga",
     "Overview" : "Apžvalga",
@@ -107,18 +110,24 @@ OC.L10N.register(
     "Personal info" : "Asmeninė informacija",
     "Mobile & desktop" : "Mobilieji ir darbalaukiai",
     "Email server" : "El. pašto serveris",
-    "Security & setup warnings" : "Saugumo ir sąrankos įspėjimai",
+    "Security & setup checks" : "Saugumo ir sąrankos patikrinimai",
     "Background jobs" : "Foninės užduotys",
     "Unlimited" : "Neribotai",
     "Verifying" : "Tikrinimas",
+    "Your remote address could not be determined." : "Nepavyko nustatyti jūsų nuotolinio adreso.",
+    "Debug mode" : "Derinimo veiksena",
+    "Debug mode is disabled." : "Derinimo veiksena yra išjungta.",
     "Disabled" : "Išjungta",
+    "You are not using MySQL" : "Jūs nenaudojate MySQL",
+    "MySQL is used as database and does support 4-byte characters" : "MySQL yra naudojama kaip duomenų bazė ir palaiko 4 baitų simbolius",
     "Supported" : "Palaikoma",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Jūsų PHP neturi FreeType palaikymo, kas savo ruožtu sąlygoja profilio paveikslėlių ir nustatymų sąsajos neteisingą atvaizdavimą.",
+    "PHP modules" : "PHP moduliai",
     "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache modulis nėra įkeltas. Geresniam našumui rekomenduojame įkelti šį modulį į savo PHP diegimą.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Yra naudojama MariaDB versija „%s“. Nextcloud 21 ir naujesnės laidos nepalaiko šios MariaDB versijos ir reikalauja 10.2 ar naujesnės versijos.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Yra naudojama MySQL versija „%s“. Nextcloud 21 ir naujesnės laidos nepalaiko šios MySQL versijos ir reikalauja MySQL 8.0 arba MariaDB 10.2, ar naujesnės versijos.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Yra naudojama PostgreSQL versija „%s“. Nextcloud 21 ir naujesnės laidos nepalaiko šios PostgreSQL versijos ir reikalauja PostgreSQL 9.6 ar naujesnės versijos.",
+    "Database version" : "Duomenų bazės versija",
+    "Unknown database platform" : "Nežinoma duomenų bazės platforma",
     "Architecture" : "Architektūra",
+    "64-bit" : "64 bitų",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilio paveikslėlis, vardas, pavardė, el. paštas, telefono numeris, adresas, svetainė, „Twitter“, organizacija, vaidmuo, santrauka apie jus, biografija bei tai, ar jūsų profilis yra įjungtas, ar ne",
     "Nextcloud settings" : "Nextcloud nustatymai",
     "Here you can decide which group can access certain sections of the administration settings." : "Čia galite nuspręsti, kuri grupė galės gauti prieigą prie tam tikrų administravimo nustatymų sekcijų.",
@@ -146,7 +155,6 @@ OC.L10N.register(
     "Save changes" : "Įrašyti pakeitimus",
     "Update to {update}" : "Atnaujinti į {update}",
     "Remove" : "Šalinti",
-    "Disable" : "Išjungti",
     "Featured" : "Siūlomos",
     "This app is supported via your current Nextcloud subscription." : "Ši programėlė yra palaikoma per jūsų esamą Nextcloud prenumeratą.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Siūlomos programėlės yra kuriamos bendruomenės viduje ir jas kuria bendruomenė. Šios programėlės siūlo svarbiausią funkcionalumą ir yra paruoštos kasdieniam naudojimui.",
@@ -162,6 +170,12 @@ OC.L10N.register(
     "_%n app has an update available_::_%n apps have an update available_" : ["%n programėlei yra prieinamas atnaujinimas","%n programėlėms yra prieinamas atnaujinimas","%n programėlių yra prieinamas atnaujinimas","%n programėlei yra prieinamas atnaujinimas"],
     "_Update_::_Update all_" : ["Atnaujinti","Atnaujinti visas","Atnaujinti visas","Atnaujinti visas"],
     "Loading" : "Įkeliama",
+    "Fetching the latest news…" : "Gaunamos paskiausios naujienos…",
+    "Previous slide" : "Ankstesnė skaidrė",
+    "Next slide" : "Kita skaidrė",
+    "Daemon" : "Tarnyba",
+    "Type" : "Tipas",
+    "Display Name" : "Rodomas vardas",
     "Description" : "Aprašas",
     "Details" : "Išsamiau",
     "All" : "Viskas",
@@ -194,6 +208,8 @@ OC.L10N.register(
     "{productName} iOS app" : "{productName} „iOS“ programėlė",
     "{productName} Android app" : "{productName} „Android“ programėlė",
     "This session" : "Šis seansas",
+    "{client} - {version} ({system})" : "{client} – {version} ({system})",
+    "{client} - {version}" : "{client} – {version}",
     "Device" : "Įrenginys",
     "Last activity" : "Paskutinė veikla",
     "Devices & sessions" : "Įrenginiai ir seansai",
@@ -237,6 +253,7 @@ OC.L10N.register(
     "Change password" : "Pakeisti slaptažodį",
     "Your profile picture" : "Jūsų profilio paveikslėlis",
     "Remove profile picture" : "Šalinti profilio paveikslėlį",
+    "The file must be a PNG or JPG" : "Failas privalo būti PNG ar JPG tipo",
     "Picture provided by original account" : "Paveikslėlis gautas iš pagrindinės paskyros",
     "Set as profile picture" : "Nustatyti kaip profilio paveikslėlį",
     "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Turėkite omenyje, kad gali praeiti iki 24 valandų, kol jūsų profilis bus visur atnaujintas.",
@@ -246,7 +263,6 @@ OC.L10N.register(
     "Error removing profile picture" : "Klaida šalinant profilio paveikslėlį",
     "Your biography" : "Jūsų biografija",
     "You are a member of the following groups:" : "Jūs esate šių grupių narys:",
-    "You are using <strong>{usage}</strong>" : "Jūs naudojate <strong>{usage}</strong>",
     "Your full name" : "Jūsų visas vardas",
     "Primary email for password reset and notifications" : "Pirminis el. paštas, skirtas slaptažodžio atstatymui bei pranešimams",
     "Email options" : "El. pašto parinktys",
@@ -262,9 +278,14 @@ OC.L10N.register(
     "Unable to delete additional email address" : "Nepavyko ištrinti papildomo el. pašto adreso",
     "No email address set" : "Nenustatytas joks el. pašto adresas",
     "Your headline" : "Santrauka apie jus",
+    "Languages" : "Kalbos",
     "Help translate" : "Padėkite išversti",
     "Unable to update language" : "Nepavyko atnaujinti kalbos",
     "No language set" : "Nenustatyta jokia kalba",
+    "Locales" : "Lokalės",
+    "Week starts on {firstDayOfWeek}" : "Savaitės pradžia yra {firstDayOfWeek}",
+    "Unable to update locale" : "Nepavyko atnaujinti lokalės",
+    "Your city" : "Jūsų miestas",
     "Your organisation" : "Jūsų organizacija",
     "Your phone number" : "Jūsų telefono numeris",
     "Edit your Profile visibility" : "Taisyti savo profilio matomumą",
@@ -284,20 +305,29 @@ OC.L10N.register(
     "Common languages" : "Bendrosios kalbos",
     "Other languages" : "Kitos kalbos",
     "Password change is disabled because the master key is disabled" : "Slaptažodžių keitimas išjungtas, nes yra išjungtas pagrindinis raktas",
-    "New user" : "Naujas naudotojas",
+    "New account" : "Nauja paskyra",
     "Display name" : "Rodomas vardas",
     "Email" : "El. paštas",
     "Quota" : "Limitas",
     "Language" : "Kalba",
+    "Add new account" : "Pridėti naują paskyrą",
     "Avatar" : "Avataras",
-    "Username" : "Naudotojo vardas",
+    "Account name" : "Paskyros pavadinimas",
     "Group admin for" : "Grupės administratorius",
-    "User backend" : "Naudotojo vidinė pusė",
     "Storage location" : "Saugyklos vieta",
     "Last login" : "Paskutinis prisijungimas",
-    "Add user to group" : "Pridėti naudotoją į grupę",
+    "Account actions" : "Veiksmai su paskyra",
+    "Loading account …" : "Įkeliama paskyra…",
+    "Set new password" : "Nustatyti naują slaptažodį",
+    "You do not have permissions to see the details of this account" : "Jūs neturite leidimo matyti išsamesnę informaciją apie šią paskyrą",
+    "Set new email address" : "Nustatyti naują el. pašto adresą",
+    "Add account to group" : "Pridėti paskyrą į grupę",
+    "Set the language" : "Nustatyti kalbą",
     "{size} used" : "{size} naudojama",
     "Delete account" : "Ištrinti paskyrą",
+    "Disconnect all devices and delete local data" : "Atjungti visus įrenginius ir ištrinti vietinius duomenis",
+    "Disable account" : "Išjungti paskyrą",
+    "Enable account" : "Įjungti paskyrą",
     "Resend welcome email" : "Siųsti dar kartą pasveikinimo el. laišką",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Pametus įrenginį arba pasikeitus darbo santykiams su organizacija, galima nuotoliniu būdu išvalyti „Nextcloud“ duomenis iš visų įrenginių, susietų su {userid}.  Veikia tik su prie interneto prijungtais įrenginiais.",
     "Remote wipe of devices" : "Nuotolinių duomenų įrenginiuose ištrynimas",
@@ -305,10 +335,13 @@ OC.L10N.register(
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Pilnai ištrinta {userid} paskyra, įskaitant visus asmeninius failus, programos duomenis ir pan. ",
     "Account deletion" : "Paskyros ištrynimas",
     "Delete {userid}'s account" : "Ištrinti naudotojo {userid} paskyrą",
+    "Password was successfully changed" : "Slaptažodis buvo sėkmingai pakeistas",
+    "Email was successfully changed" : "El. paštas buvo sėkmingai pakeistas",
     "Welcome mail sent!" : "Pasveikinimo laiškas išsiųstas!",
     "Done" : "Atlikta",
     "Edit" : "Taisyti",
     "Visibility" : "Matomumas",
+    "Show language" : "Rodyti kalbą",
     "Show storage path" : "Rodyti saugyklos kelią",
     "Show last login" : "Rodyti paskutinį prisijungimą",
     "Sorting" : "Rikiavimas",
@@ -327,14 +360,18 @@ OC.L10N.register(
     "The following devices are configured for your account:" : "Jūsų paskyrai sukonfiguruoti šie įrenginiai:",
     "Your browser does not support WebAuthn." : "Jūsų naršyklė nepalaiko WebAuthn.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Būdami administratoriumi, galite reguliuoti bendrinimo elgseną. Išsamesnei informacijai, žiūrėkite dokumentaciją.",
+    "All accounts" : "Visos paskyros",
     "Admins" : "Administratoriai",
-    "New account" : "Nauja paskyra",
+    "Creating group…" : "Kuriama grupė…",
+    "Create group" : "Sukurti grupę",
     "Group name" : "Grupės pavadinimas",
+    "Failed to create group" : "Nepavyko sukurti grupės",
     "Sending…" : "Siunčiama…",
     "Email sent" : "El. paštas išsiųstas",
     "Location" : "Vieta",
     "Profile picture" : "Profilio paveikslėlis",
     "About" : "Apie",
+    "Date of birth" : "Gimimo data",
     "Full name" : "Vardas, pavardė",
     "Additional email" : "Papildomas el. paštas",
     "Headline" : "Santrauka",
@@ -344,27 +381,31 @@ OC.L10N.register(
     "Website" : "Svetainė",
     "Profile visibility" : "Profilio matomumas",
     "Locale" : "Lokalė",
+    "First day of week" : "Pirmoji savaitės diena",
     "Your apps" : "Jūsų programėlės",
     "Active apps" : "Aktyvios programėlės",
     "Disabled apps" : "Išjungtos programėlės",
     "Updates" : "Atnaujinimai",
     "App bundles" : "Programėlių rinkiniai",
     "Featured apps" : "Siūlomos programėlės",
+    "Supported apps" : "Palaikomos programėlės",
     "Show to everyone" : "Rodyti visiems",
     "Hide" : "Slėpti",
     "Download and enable" : "Atsisiųsti ir įjungti",
+    "Disable" : "Išjungti",
     "The app will be downloaded from the App Store" : "Programėlė bus atsisiųsta iš programėlių parduotuvės",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ši programėlė nėra pažymėta kaip suderinama su jūsų Nextcloud versija. Jei tęsite, vis tiek galėsite įdiegti programėlę. Turėkite omenyje, kad programėlė gali neveikti taip, kaip tikimasi.",
     "Never" : "Niekada",
     "An error occurred during the request. Unable to proceed." : "Užklausos metu įvyko klaida. Nepavyksta tęsti.",
-    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Programėlė įjungta, tačiau turi būti atnaujinta. Po 5 sekundžių būsite peradresuoti į atnaujinimo puslapį.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Klaida: Ši programėlė negali būti įjungta, nes ji neigiamai veikia serverio stabilumą",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Programėlė įjungta, tačiau turi būti atnaujinta. Po 5 sekundžių būsite peradresuoti į atnaujinimo puslapį.",
     "Do you really want to wipe your data from this device?" : "Ar tikrai norite ištrinti šiame įrenginyje esančius savo duomenis?",
     "Confirm wipe" : "Patvirtinti duomenų ištrynimą",
     "Error while wiping the device with the token" : "Įvyko klaida valant įrenginį panaudojant raktą",
     "Error while updating device token name" : "Įvyko klaida atnaujinant įrenginio prieigos rakto pavadinimą",
     "Error while updating device token scope" : "Įvyko klaida atnaujinant įrenginio prieigos rakto taikymą",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Iš jūsų tinklo buvo per daug užklausų. Bandykite dar kartą vėliau arba, jeigu tai klaida, susisiekite su savo administratoriumi.",
+    "Error" : "Klaida",
     "Forum" : "Forumas",
     "Legal notice" : "Teisinis pranešimas",
     "Privacy policy" : "Privatumo politika",
@@ -383,6 +424,7 @@ OC.L10N.register(
     "SMTP Password" : "SMTP slaptažodis",
     "Save" : "Įrašyti",
     "Test and verify email settings" : "Išbandyti ir patikrinti el. pašto nustatymus",
+    "Security & setup warnings" : "Saugumo ir sąrankos įspėjimai",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Siekiant jūsų egzemplioriaus saugumo ir našumo, yra svarbu, kad viskas būtų teisingai sukonfigūruota. Norėdami jums padėti, atliekame tam tikrus automatinius patikrinimus. Išsamesnei informacijai, žiūrėkite susietą dokumentaciją.",
     "All checks passed." : "Visi patikros rezultatai teigiami.",
     "There are some errors regarding your setup." : "Yra klaidų, susijusių su jūsų sąranką.",
@@ -393,83 +435,56 @@ OC.L10N.register(
     "Reasons to use Nextcloud in your organization" : "Priežastys, kodėl turėtumėte naudoti Nextcloud savo organizacijoje",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Sukurta {communityopen}Nextcloud bendruomenės{linkclose}, {githubopen}pirminis kodas{linkclose} yra licencijuotas pagal {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Spauskite „Patinka“ mūsų „Facebook“ puslapyje",
-    "Follow us on Twitter" : "Sekite mus Twitter",
     "Follow us on Mastodon" : "Sekite mus Mastodon",
     "Check out our blog" : "Peržvelkite mūsų tinklaraštį",
     "Subscribe to our newsletter" : "Prenumeruokite mūsų naujienlaiškį",
     "Use a second factor besides your password to increase security for your account." : "Be savo slaptažodžio naudokite ir antrąjį faktorių, kad padidintumėte savo paskyros saugumą.",
     "No user supplied" : "Nepateiktas naudotojas",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Pateikite administratoriaus atkūrimo slaptažodį; kitu atveju visi naudotojo duomenis bus prarasti.",
-    "Federated Cloud Sharing" : "Bendrinimas federacinėje debesijoje",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL naudoja pasenusią %1$s versiją (%2$s). Atnaujinkite savo operacinę sistemą arba tokios ypatybės kaip %3$s neveiks patikimai.",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Nepavyko nustatyti ar TLS versija, priklausanti cURL, yra pasenusi ar ne, nes į https://nextcloud.com siunčiamos HTTPS užklausos metu įvyko klaida. Išsamesnei informacijai patikrinkite Nextcloud žurnalo failą.",
-    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache yra išjungtas. Geresniam našumui rekomenduojame taikyti savo PHP konfigūracijoje <code>opcache.enable=1</code>.",
-    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache yra sukonfigūruotas taip, kad šalintų kodo komentarus. Turint įjungtą OPcache, privalo būti nustatyta <code>opcache.save_comments=1</code>, kad Nextcloud galėtų funkcionuoti.",
     "You need to set your user email before being able to send test emails. Go to %s for that." : "Prieš tai, kai galėsite siųsti bandomuosius el. laiškus, turite nusistatyti naudotojo el. paštą. Norėdami tai atlikti, pereikite į %s.",
     "Invalid user" : "Neteisingas naudotojas",
     "Your username is: %s" : "Jūsų naudotojo vardas yra: %s",
     "Logged in user must be a subadmin" : "Prisijungęs naudotojas privalo būti administratoriaus pavaduotojas",
+    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Yra naudojama MariaDB versija „%s“. Nextcloud 21 ir naujesnės laidos nepalaiko šios MariaDB versijos ir reikalauja 10.2 ar naujesnės versijos.",
+    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Yra naudojama MySQL versija „%s“. Nextcloud 21 ir naujesnės laidos nepalaiko šios MySQL versijos ir reikalauja MySQL 8.0 arba MariaDB 10.2, ar naujesnės versijos.",
+    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Yra naudojama PostgreSQL versija „%s“. Nextcloud 21 ir naujesnės laidos nepalaiko šios PostgreSQL versijos ir reikalauja PostgreSQL 9.6 ar naujesnės versijos.",
+    "Exclude groups from sharing" : "Išskirti grupes iš bendrinimo",
+    "These groups will still be able to receive shares, but not to initiate them." : "Šios grupės vis tiek galės gauti viešinius, tačiau negalės jų inicijuoti.",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dviejų faktorių tapatybės nustatymas gali būti priverstinis visiems naudotojams ir tam tikroms grupėms. Jeigu naudotojai ar grupės neturės sukonfigūruoto dviejų faktorių teikėjo, tuomet jie negalės prisijungti prie sistemos.",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Jei nepasirinkta nė viena grupė, 2FA įjungiama visiems, išskyrus pašalintų grupių narius. Jei pasirenkamos grupės, visiems jų nariams įjungiama 2FA. Jei vartotojas yra ir pasirinktoje, ir pašalintoje grupėje,  2FA yra įjungiamas. ",
-    "Enable all" : "Įjungti visas",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Sync client - {os}" : "Sinchronizavimo klientas - {os}",
-    "Error while deleting the token" : "Klaida, ištrinant prieigos raktą",
-    "Use the credentials below to configure your app or device." : "Naudokite žemiau esančius prisijungimo duomenis, kad galėtumėte konfigūruoti programėlę ar įrenginį.",
-    "For security reasons this password will only be shown once." : "Saugumo sumetimais šis slaptažodis bus parodytas tik vieną kartą.",
-    "Copied!" : "Nukopijuota!",
-    "Copy" : "Kopijuoti",
+    "{license}-licensed" : "Licencijuota pagal {license}",
+    "Username" : "Naudotojo vardas",
     "Execute one task with each page loaded. Use case: Single user instance." : "Su kiekvienu įkeltu puslapiu vykdyti po vieną užduotį. Naudojimo atvejis: Egzempliorius su vienu naudotoju.",
     "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "„cron.php“ yra registruojamas „webcron“ tarnyboje, kad kas 5 minutes per HTTP būtų iškviečiamas failas „cron.php“. Naudojimo atvejis: Labai mažas egzempliorius (priklausomai nuo našumo, 1–5 naudotojai).",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Norint tai paleisti, jums reikia PHP POSIX plėtinio. Išsamesnei informacijai, žiūrėkite {linkstart}PHP dokumentaciją{linkend}.",
-    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Naudoti sistemos „cron“ tarnybą, kad kas 5 minutes būtų iškviečiamas failas „cron.php“. Rekomenduojama visiems egzemplioriams.",
     "The cron.php needs to be executed by the system user \"{user}\"." : "Failą „cron.php“ turi vykdyti sistemos naudotojas „{user}“.",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Jūs ketinate pašalinti grupę {group}. Naudotojai NEBUS ištrinti.",
-    "Please confirm the group removal " : "Patvirtinkite grupės pašalinimą",
-    "Your email address" : "Jūsų el. pašto adresas",
+    "You are using <strong>{usage}</strong>" : "Jūs naudojate <strong>{usage}</strong>",
     "Additional emails" : "Papildomi el. paštai",
     "Enable Profile" : "Įjungti profilį",
-    "Your Twitter handle" : "Jūsų „Twitter“ rankenėlė",
+    "Loading users …" : "Įkeliami naudotojai…",
+    "New user" : "Naujas naudotojas",
+    "Add new user" : "Pridėti naują naudotoją",
+    "User backend" : "Naudotojo vidinė pusė",
+    "Loading user …" : "Įkeliamas naudotojas…",
     "You do not have permissions to see the details of this user" : "Jūs neturite leidimų matyti išsamesnę informaciją apie šį naudotoją",
-    "Add new password" : "Pridėti naują slaptažodį",
-    "Add new email address" : "Pridėti naują el. pašto adresą",
+    "Add user to group" : "Pridėti naudotoją į grupę",
     "Set user as admin for" : "Nustatyti vartotoją kaip administratorių ",
     "Select user quota" : "Pasirinkite leidžiamą duomenų kiekį naudotojui",
-    "Toggle user actions menu" : "Perjungti vartotojo veiksmų meniu ",
     "Delete user" : "Ištrinti naudotoją",
     "Wipe all devices" : "Ištrinti duomenis visuose įrenginiuose",
     "Disable user" : "Išjungti naudotoją",
     "Enable user" : "Įjungti naudotoją",
-    "Edit User" : "Taisyti naudotoją",
-    "Will be autogenerated" : "Bus automatiškai sugeneruotas ",
-    "Add a new user" : "Pridėti naują naudotoją",
-    "No users in here" : "Čia naudotojų nėra",
+    "Toggle user actions menu" : "Perjungti vartotojo veiksmų meniu ",
+    "Show user backend" : "Rodyti naudotojo vidinę pusę",
     "Name your device" : "Pavadinkite savo įrenginį",
     "Server error while trying to add WebAuthn device" : "Serverio klaida, bandant pridėti WbAuthn įrenginį",
-    "{license}-licensed" : "Licencijuota pagal {license}",
     "by {author}\n{license}" : "pagal {author}\n{license}",
-    "Enter group name" : "Įveskite grupės pavadinimą",
-    "Add group" : "Pridėti grupę",
     "Active users" : "Aktyvūs naudotojai",
     "Disabled users" : "Išjungti naudotojai",
-    "Default quota:" : "Numatytasis leidžiamas duomenų kiekis:",
-    "Show Languages" : "Rodyti kalbas",
-    "Show user backend" : "Rodyti naudotojo vidinę pusę",
-    "Send email to new user" : "Siųsti naujam naudotojui el. laišką",
-    "Not saved" : "Neįrašyta",
-    "Twitter" : "Twitter",
+    "Creating group …" : "Kuriama grupė…",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Neprieinama, nes su naudotoju susijusios informacijos paskelbimas į paieškos serverį yra neleidžiamas. Jei turite klausimų, susisiekite su savo sistemos administratoriumi",
     "Show to logged in users only" : "Rodyti tik prisijungusiems naudotojams",
-    "Enable untested app" : "Įjungti netestuotą programą",
     "SMTP Username" : "SMTP naudotojo vardas",
-    "Set default expiration date" : "Nustatyti numatytąją galiojimo pabaigos datą",
-    "Exclude groups from sharing" : "Išskirti grupes iš bendrinimo",
-    "These groups will still be able to receive shares, but not to initiate them." : "Šios grupės vis tiek galės gauti viešinius, tačiau negalės jų inicijuoti."
+    "Follow us on Twitter" : "Sekite mus Twitter",
+    "Active accounts" : "Aktyvios paskyros"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
