@@ -5,24 +5,24 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory." : "يمكن عادةً إصلاح ذلك من خلال منح خادم الويب حق الوصول للكتابة إلى دليل التكوين config directory.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "ولكن، إذا كنت تُفضّل الاحتفاظ بملف config.php للقراءة فقط، فعيّن الخيار \"config_is_read_only\" إلى \"صح\" \"True\".",
     "See %s" : "أنظر%s",
-    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "التطبيق %1$s غير موجود أو ليس له إصدار متطابق مع هذا الخادوم. رجاءً، راجع دليل التطبيقات apps directory.",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "التطبيق %1$s غير موجود أو ليس له إصدار متطابق مع هذا الخادم. رجاءً، راجع دليل التطبيقات apps directory.",
     "Sample configuration detected" : "تمّ العثور على عيّنة إعدادات.",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "تمّ اكتشاف أن عيّنة الإعدادات قد تمّ نسخها. يُمكن لهذا أن يُعطّل عملية التنصيب و هو أمر غير مدعوم. نرجو الاطلاع على التعليمات الواردة في وثائق النظام قبل إحداث أي تعديلات على ملف config.php",
-    "The page could not be found on the server." : "تعذّر العثور على الصفحة في الخادوم",
+    "The page could not be found on the server." : "تعذّر العثور على الصفحة في الخادم",
     "%s email verification" : "%s التحقّق من الإيميل",
     "Email verification" : "التحقّق من الإيميل",
     "Click the following button to confirm your email." : "إضغط الزر التالي لتأكيد الإيميل",
     "Click the following link to confirm your email." : "إضغط الرابط التالي لتأكيد الإيميل",
     "Confirm your email" : "قم بتأكيد إيميلك",
-    "Other activities" : "حركات أخرى",
+    "Other activities" : "أنشطة أخرى",
     "%1$s and %2$s" : "%1$s و %2$s",
     "%1$s, %2$s and %3$s" : "%1$s، %2$s و %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s، %2$s، %3$s و %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s، %2$s، %3$s، %4$s و %5$s",
-    "Education Edition" : "الإصدار التعليمي",
+    "Education bundle" : "الحزمة التعليمية",
     "Enterprise bundle" : "حزمة المؤسسة",
     "Groupware bundle" : "حزمة أدوات العمل الجماعي",
-    "Hub bundle" : "حزمة الـ\"هَبْ\" Hub",
+    "Hub bundle" : "حزمة نقطة التواصل",
     "Public sector bundle" : "حزمة القطاع العام",
     "Social sharing bundle" : "حزمة المشاركة الاجتماعية",
     "PHP %s or higher is required." : "إصدار PHP %s أو أحدث منه مطلوب.",
@@ -37,9 +37,10 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "المنصّات التالية مدعومة: %s",
     "Server version %s or higher is required." : "مطلوب إصدار الخادم %s أو أعلى.",
     "Server version %s or lower is required." : "مطلوب إصدار الخادم %s أو أقل.",
-    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "الداخل للحساب يجب أن يكون مُشرفاً أو مشرفاً فرعيّاً أو يملك حقاً خاصاً للوصول إلى هذا الإعداد",
-    "Logged in account must be an admin or sub admin" : "الداخل للحساب يجب أن يكون مُشرفاً أو مشرفاً فرعيّاً ",
-    "Logged in account must be an admin" : "الداخل للحساب يجب أن يكون مُشرفاً ",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "الحساب المسجل دخوله يجب أن يكون حساب مدير أو مدير فرعي أو يملك حقاً خاصاً للوصول إلى هذا الإعداد",
+    "Your current IP address doesn’t allow you to perform admin actions" : "عنوانك الحالي IP يمنعك من أداء مهام المدير",
+    "Logged in account must be an admin or sub admin" : "الحساب المسجل دخوله يجب أن يكون حساب مدير أو مدير فرعي",
+    "Logged in account must be an admin" : "الحساب المسجل دخوله يجب أن يكون حساب مدير",
     "Wiping of device %s has started" : "بدأ مسح الجهاز %s ",
     "Wiping of device »%s« has started" : "بدأ مسح الجهاز »%s« ",
     "»%s« started remote wipe" : "»%s« بدأ المسح عن بُعدٍ",
@@ -60,8 +61,8 @@ OC.L10N.register(
     "View profile" : "عرض الملف الشخصي",
     "Local time: %s" : "الوقت المحلّي: %s",
     "today" : "اليوم",
-    "tomorrow" : "غدًا",
-    "yesterday" : "يوم أمس",
+    "tomorrow" : "يوم غد",
+    "yesterday" : "البارحة",
     "_in %n day_::_in %n days_" : ["في %nأيام","في %nيوم","في %nأيام","في %nأيام","في %n أيام","في %nأيام"],
     "_%n day ago_::_%n days ago_" : ["قبل ساعات","قبل يوم","قبل يومين","قبل %n يوماً","قبل %n يوماً","قبل %n يوماً"],
     "next month" : "الشهر القادم",
@@ -76,35 +77,42 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n منذ ساعات","%n منذ ساعة","%n منذ ساعات","%n منذ ساعات","%n منذ ساعات","%n منذ ساعات"],
     "_in %n minute_::_in %n minutes_" : ["في %nدقائق","في %nدقيقة","في %nدقائق","في %nدقائق","في %nدقائق","في %nدقائق"],
     "_%n minute ago_::_%n minutes ago_" : ["%n منذ دقائق","%n منذ دقيقة","%n منذ دقائق","%n منذ دقائق","%n منذ دقائق","%n منذ دقائق"],
-    "in a few seconds" : "خلال بضع ثواني",
-    "seconds ago" : "منذ ثواني",
+    "in a few seconds" : "خلال بضع ثوانٍ",
+    "seconds ago" : "منذ ثوانٍ",
     "Empty file" : "ملفٌ فارغٌ",
-    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "الوحدة module ذات الرقم ID ـ : %s غير موجودة. رجاءً، فعّلها في إعدادات التطبيقات لديك، أو اتصل بمشرف نظامك.",
+    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "الوحدة module ذات الرقم ID ـ : %s غير موجودة. رجاءً، فعّلها في إعدادات التطبيقات لديك، أو اتصل بمسؤول النظام.",
+    "Dot files are not allowed" : "الملفات النقطية (ملفات ذات أسماء تبدأ بنقطة) غير مسموح بها",
+    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" غير مسموح به أن يكون اسم ملف أو مجلد.",
+    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" غير مسموح به أن يكون بادئة لاسم ملف أو مجلد.",
+    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" غير مسموح به أن يكون داخل اسم ملف أو مجلد.",
+    "\"%1$s\" is a forbidden file type." : "\"%1$s\" غير مسموح به كنوع لملف.",
+    "Filenames must not end with \"%1$s\"." : "أسماء الملفات يجب ألّا تنتهي بـ \"%1$s\".",
+    "Invalid parent path" : "مسار المجلد الأب غير صالح",
     "File already exists" : "الملف موجود مسبقاً",
-    "Invalid path" : "مسارٌ غير صحيحٍ",
+    "Invalid path" : "مسار غير صالح !",
     "Failed to create file from template" : "تعذّر إنشاء ملفٍ من قالبٍ",
     "Templates" : "القوالب",
-    "File name is a reserved word" : "اسم الملف كلمة محجوزة",
-    "File name contains at least one invalid character" : "اسم الملف به ، على الأقل ، حرف غير صالح",
-    "File name is too long" : "اسم الملف طويل جداً",
-    "Dot files are not allowed" : "الملفات النقطية (ملفات ذات أسماء تبدأ بنقطة) غير مسموح بها",
+    "Path contains invalid segments" : "يحتوي المسار على أجزاء غير صحيحة",
+    "Filename is a reserved word" : "اسم الملف غير مقبوله لأنه كلمة محجوزة",
+    "Filename contains at least one invalid character" : "اسم الملف به على الأقل حرفٌ غير صالح",
+    "Filename is too long" : "اسم الملف أطول مما يجب",
     "Empty filename is not allowed" : "لا يسمح بأسماء فارغة للملفات",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "لا يمكن تثبيت التطبيق \"%s\" لأنه لا يمكن قراءة ملف معلومات التطبيق.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "لا يمكن تثبيت التطبيق \"%s\" لأنه غير متوافق مع هذا الإصدار من الخادم.",
     "__language_name__" : "اللغة العربية",
     "This is an automatically sent email, please do not reply." : "هذه رسالة آلية، يرجى عدم الرد عليها.",
-    "Help & privacy" : "المساعدة و الخصوصية",
-    "Appearance and accessibility" : "المظهر  و سهولة الوصول.",
+    "Help & privacy" : "المساعدة والخصوصية",
+    "Appearance and accessibility" : "المظهر وسهولة الوصول",
     "Apps" : "التطبيقات",
     "Personal settings" : "إعدادات شخصيّة",
     "Administration settings" : "إعدادات الإدارة",
     "Settings" : "الإعدادات",
     "Log out" : "الخروج",
-    "Users" : "المستخدمين",
+    "Accounts" : "الحسابات",
     "Email" : "البريد الإلكتروني",
     "Mail %s" : "بريد %s",
-    "Fediverse" : "الشبكة اللامركزية للتواصل الاجتماعي \"فيديفيرس\" Fediverse",
-    "View %s on the fediverse" : "عرض %s على الفيديفيرس.",
+    "Fediverse" : "الشبكة اللامركزية للتواصل الاجتماعي Fediverse",
+    "View %s on the fediverse" : "عرض %s على Fediverse.",
     "Phone" : "الهاتف",
     "Call %s" : "إتصل بـ%s",
     "Twitter" : "تويتر",
@@ -114,10 +122,11 @@ OC.L10N.register(
     "Address" : "العنوان",
     "Profile picture" : "صورة الملف الشخصي",
     "About" : "عن",
-    "Display name" : "الاسم المعروض",
+    "Display name" : "اسم العرض",
     "Headline" : "عنوان ",
     "Organisation" : "مؤسسة",
     "Role" : "الدور",
+    "Pronouns" : "الضمائر",
     "Unknown account" : "حساب غير معروف",
     "Additional settings" : "الإعدادات المتقدمة",
     "Enter the database Login and name for %s" : "أدخِل مُعرف تسجيل الدخول و الاسم الخاص بقاعدة البيانات %s",
@@ -125,7 +134,7 @@ OC.L10N.register(
     "Enter the database name for %s" : "أدخل اسم قاعدة البيانات لـ%s",
     "You cannot use dots in the database name %s" : "لا يمكنك استخدام النقاط dots في اسم قاعدة البيانات %s",
     "MySQL Login and/or password not valid" : "مُعرف تسجل الدخول او كلمة مرور MySQL غير صحيحة",
-    "You need to enter details of an existing account." : "يلزمك إدخال تفاصيل حسابك الحالي.",
+    "You need to enter details of an existing account." : "يتوجب عليك إدخال تفاصيل لحساب موجود.",
     "Oracle connection could not be established" : "لم تنجح محاولة اتصال Oracle",
     "Oracle Login and/or password not valid" : "مُعرف تسجيل الدخول او كلمة مرور Oracle غير صحيحة",
     "PostgreSQL Login and/or password not valid" : "مُعرف تسجيل دخول او كلمة مرور PostgreSQL غير صحيحة",
@@ -133,32 +142,68 @@ OC.L10N.register(
     "For the best results, please consider using a GNU/Linux server instead." : "فضلاً ضع في الاعتبار استخدام نظام GNU/Linux بدل الأنظمة الأخرى للحصول على أفضل النتائج.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "يبدو أن كائن %s يعمل على بيئة PHP 32-Bit  وكذلك تم تكوين open_basedir في ملف php.ini. يؤدي ذلك إلى مشاكل مع الملفات التي يزيد حجمها عن 4 غيغابايت ولا يُنصح بذلك بشدة.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "فضلاً إحذف إعداد open_basedir من ملف php.ini لديك أو حوّل إلى PHP إصدار 64 بت.",
-    "Set an admin Login." : "تعيين مُعرف تسجيل دخول المشرف.",
-    "Set an admin password." : "تعيين كلمة مرور للمشرف",
+    "Set an admin Login." : "تعيين مُعرف تسجيل دخول المدير.",
+    "Set an admin password." : "تعيين كلمة مرور للمدير",
     "Cannot create or write into the data directory %s" : "لا يمكن الإنشاء أو الكتابة في دليل البيانات %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "يجب أن تقوم الواجهة الخلفية للمشاركة (Sharing backend) %s بتطبيق الواجهة OCP\\Share_Backend",
     "Sharing backend %s not found" : "لم يتم العثور على الواجهة الخلفية (Sharing backend)  %s",
     "Sharing backend for %s not found" : "مشاركة الخلفية لـ %s غير موجود",
+    "%1$s shared »%2$s« with you" : "%1$s شارك »%2$s« معك",
+    "%1$s shared »%2$s« with you." : "%1$s شَارَكَ »%2$s« معك.",
+    "Click the button below to open it." : "اضغط على الزر الذي تحته ليتم فتحه.",
+    "Open »%s«" : "فتح »%s«",
+    "%1$s via %2$s" : "%1$s عبر %2$s",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s شارك »%2$s« معك و يرغب في إضافة:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s شارك »%2$s« معك و يرغب في إضافة",
     "»%s« added a note to a file shared with you" : "»%s« أضاف ملاحظة لملفٍ سلفت مشاركته معك",
-    "Open »%s«" : "فتح »%s«",
-    "%1$s via %2$s" : "%1$s عبر %2$s",
+    "Passwords are enforced for link and mail shares" : "كلمة المرور مطلوبة للمشاركات عن طريق الروابط و البريد الإلكتروني",
+    "Share recipient is not a valid user" : "مُستلِم المشاركة ليس مستخدِماً صالحاً",
+    "Share recipient is not a valid group" : "مُستلِم المشاركة ليس مجموعةً صالحةً",
+    "Share recipient should be empty" : "مُستلِم المشاركة يجب أن يكون فارغاً",
+    "Share recipient should not be empty" : "مُستلِم المشاركة يجب ألّا يكون فارغاً",
+    "Share recipient is not a valid circle" : "مُستلِم المشاركة ليس حلقة اتصال صالحة",
+    "Unknown share type" : "نوع مشاركة غير معروف",
+    "Share initiator must be set" : "مُنشِيء المشاركة يجب تعيينه",
+    "Cannot share with yourself" : "لا يمكنك المشاركة مع نفسك",
+    "Shared path must be set" : "مسار المشاركة يجب تعيينه",
+    "Shared path must be either a file or a folder" : "مسار المشاركة يجب أن يكون إمّا ملفاً أو مجلداً",
+    "You cannot share your root folder" : "لا يمكنك مشاركة مجلدك الجذر",
     "You are not allowed to share %s" : "أنت غير مسموح لك أن تشارك %s",
+    "Valid permissions are required for sharing" : "المشاركة تلزمها أذونات صالحة",
     "Cannot increase permissions of %s" : "لا يمكن زيادة أذونات %s",
+    "Shares need at least read permissions" : "المشاركات تتطلب في الحد الأدنى إذناً بالقراءة",
     "Files cannot be shared with delete permissions" : "لا يمكن مشاركة ملفات بأذونات حذفٍ",
     "Files cannot be shared with create permissions" : "لا يمكن مشاركة ملفات بأذونات إنشاء",
     "Expiration date is in the past" : "تاريخ انتهاء الصلاحية غير صالح.  التاريخ المحدد في الماضي!",
+    "Expiration date is enforced" : "تاريخ انتهاء الصلاحية مطلوب",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر من %n أيام في المستقبل","لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر من %n يوم في المستقبل","لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر %n من أيام في المستقبل","لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر %n من أيام في المستقبل","لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر %n من أيام في المستقبل","لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر %n من أيام في المستقبل"],
-    "Sharing is only allowed with group members" : "المشاركة مسموحة فقط مع أعضاء المجموعة",
+    "Sharing is only allowed with group members" : "المشاركة مسموح بها فقط مع أعضاء المجموعة.",
     "Sharing %s failed, because this item is already shared with the account %s" : "فشلت مشاركة %s؛ لأن هذا العنصر سبقت مشاركته مع الحساب %s",
-    "%1$s shared »%2$s« with you" : "%1$s شارك »%2$s« معك",
-    "%1$s shared »%2$s« with you." : "%1$s شَارَكَ »%2$s« معك.",
-    "Click the button below to open it." : "أنقر على الزر أدناه لفتحه.",
+    "Group sharing is now allowed" : "المشاركة مع المجموعات غير مسموحة",
+    "Sharing is only allowed within your own groups" : "المشاركة مسموحة فقط ضمن مجموعتك الخاصة",
+    "Path is already shared with this group" : "المسار تمّت مشاركته سلفاً مع هذه المجموعة",
+    "Link sharing is not allowed" : "المشاركة عبر الروابط غير مسموحة",
+    "Public upload is not allowed" : "الرفع من قِبَل العموم غير مسموح به",
+    "Path contains files shared with you" : "يحتوي المسار على ملفات تمّت مشاركتها معك",
+    "Sharing is disabled" : "المشاركة معطلة",
+    "Sharing is disabled for you" : "المشاركة معطلة بالنسبة لك",
+    "Cannot share with the share owner" : "لا يمكنك المشاركة مع مالك المشاركة",
+    "Share does not have a full ID" : "المشاركة ليس لها مُعرِّف ID كامل",
+    "Cannot change share type" : "لا يمكن تغيير نوع المشاركة",
+    "Can only update recipient on user shares" : "يمكن فقط تحديث المستلم على مشاركات المستخدم",
+    "Cannot enable sending the password by Talk with an empty password" : "لا يمكن تمكين إرسال كلمة المرور عن طريق برنامج \"المحادثة\" Talk بكلمة مرور فارغة",
+    "Cannot enable sending the password by Talk without setting a new password" : "لا يمكن تمكين إرسال كلمة المرور عن طريق برنامج \"المحادثة\" Talk بدون تعيين كلمة مرور جديدة",
+    "Cannot disable sending the password by Talk without setting a new password" : "لا يمكن تعطيل إرسال كلمة المرور عن طريق برنامج \"المحادثة\" Talk بدون تعيين كلمة مرور جديدة",
+    "Share provider does not support accepting" : "مزود المشاركة لا يدعم خاصية خيار القبول",
+    "Cannot change target of link share" : "لا يمكن تغيير مَقصِد مشاركة الرابط",
+    "Invalid share recipient" : "مُستلِم المشاركة غير صالح",
+    "Group \"%s\" does not exist" : "المجموعة \"%s\" غير موجودة",
     "The requested share does not exist anymore" : "المشاركة المطلوبة لم تعد موجودةً",
-    "The requested share comes from a disabled user" : "المستخدم الذي طلب المشاركة تمّ تجميد حسابه بعد طلبه للمشاركة",
-    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "لم يتم إنشاء المستخدم بسبب وصول عدد المستخدمين إلى الحد الأقصى المسموح به. رجاءً، راجع إشعاراتك للمزيد من المعلومات.",
+    "The requested share comes from a disabled user" : "المشاركة المطلوبة آتية من مستخدم معطل.",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "تعذر إنشاء المستخدم بسبب تجاوز الحد الأقصى لعدد المستخدمين المسموح به. يرجى الرجوع إلى الإشعارات لمزيد من التفاصيل.",
     "Could not find category \"%s\"" : "تعذر العثور على المجلد \"%s\"",
+    "Input text" : "إدخال نص",
+    "The input text" : "النص المدخل",
     "Sunday" : "الأحد",
     "Monday" : "الإثنين",
     "Tuesday" : "الثلاثاء",
@@ -216,23 +261,21 @@ OC.L10N.register(
     "Login canceled by app" : "تم إلغاء تسجيل الدخول مِن طرف التطبيق",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "التطبيق \"%1$s\" لا يمكن تنصيبه بسبب أن التبعيّات التالية لم تتحقق: %2$s",
     "a safe home for all your data" : "المكان الآمن لجميع بياناتك",
-    "File is currently busy, please try again later" : "إنّ الملف مشغول الآمن، يرجى إعادة المحاولة لاحقًا",
-    "Cannot download file" : "لا يمكن تنزيل الملف",
     "Application is not enabled" : "التطبيق غير مفعّل",
     "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
     "Token expired. Please reload page." : "انتهت صلاحية الكلمة , يرجى اعادة تحميل الصفحة",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "لا توجد برامج تشغيل لقاعدة البيانات (sqlite أو mysql أو postgresql) مثبتة.",
     "Cannot write into \"config\" directory." : "تعذّرت الكتابة في الدليل 'config\".",
-    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "يمكن إصلاح هذا عادةً بمنح خادوم الوب صلاحية الوصول إلى الدليل \"config\". للمزيد، أنظر: %s",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "يمكن إصلاح هذا عادةً بمنح خادم الويب صلاحية الوصول إلى الدليل \"config\". للمزيد، أنظر: %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "و إذا كنت تُفضّل بقاء الملف \"config.php\" للقراءة فقط، عيّن الخيار  \"config_is_read_only\". أنظر: %s",
     "Cannot write into \"apps\" directory." : "لا يمكن الكتابة في الدليل \"apps\".",
     "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "يمكن إصلاح ذلك عادةً عن طريق منح خادم الويب حق الكتابة في دليل التطبيقات في الملف او تعطيل متجر تطبيقات ابل في ملف \"config\".",
     "Cannot create \"data\" directory." : "لا يمكن إنشاء ملف بيانات",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "يمكن إصلاح ذلك عادةً عن طريق منح خادم الويب حق الكتابة في الدليل الجذري root directory.  أنطر:%s",
-    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "الأذونات يمكن إصلاحها عادةً عن طريق منح خادم الويب حق الكتابة في الدليل الجذري root directory. أنظر:%s.",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "الصلاحيات يمكن إصلاحها عادةً عن طريق منح خادم الويب حق الكتابة في الدليل الجذري root directory. أنظر:%s.",
     "Your data directory is not writable." : "دليل البيانات data directory لا يمكن الكتابة فيه.",
-    "Setting locale to %s failed." : "تعذّر تعيين إعدادت اللغة و المَحلّيّات locale إلى %s.",
-    "Please install one of these locales on your system and restart your web server." : "الرجاء تثبيت إحدى هذه المناطق على نظامك وإعادة تشغيل خادوم الويب الخاص بك.",
+    "Setting locale to %s failed." : "فشل تعيين إعدادات المنطقة واللغة إلى %s.",
+    "Please install one of these locales on your system and restart your web server." : "الرجاء تثبيت إحدى هذه المناطق على نظامك وإعادة تشغيل خادم الويب الخاص بك.",
     "PHP module %s not installed." : "وحدة PHP %s غير مثبتة.",
     "Please ask your server administrator to install the module." : "يرجى مطالبة مسؤول الخادم بتثبيت الوحدة.",
     "PHP setting \"%s\" is not set to \"%s\"." : "إعداد PHP  \"%s\" لم يتم تعيينه إلى \"%s\".",
@@ -244,16 +287,16 @@ OC.L10N.register(
     "PHP modules have been installed, but they are still listed as missing?" : "تم تثبيت وحدات PHP ، لكنها لا تزال مدرجة على أنها وحدات مفقودة؟",
     "Please ask your server administrator to restart the web server." : "يرجى مطالبة مسؤول الخادم بإعادة تشغيل خادم الويب.",
     "The required %s config variable is not configured in the config.php file." : "مُتغيّر التهيئة %s المطلوب لم تتم تهيئته في الملف config.php.",
-    "Please ask your server administrator to check the Nextcloud configuration." : "رجاءً، أطلب من مشرف نظامك مراجعة تهيئة نكست كلاود Nextcloud configuration.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "رجاءً، أطلب من مسؤول النظام مراجعة تهيئة نكست كلاود.",
     "Your data directory is readable by other people." : "دليل بياناتك مسموحٌ بقراءته من قِبَل أشخاص آخرين.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "قُم رجاءً بتغيير الأذونات إلى 0770 حتى لا يتسنّى لأشخاص آخرين استعراض الدليل.",
     "Your data directory must be an absolute path." : "مسار دليل بياناتك data directory يجب أن يكون مساراً مُطلقاً absolute path.",
     "Check the value of \"datadirectory\" in your configuration." : "راجع قيمة \"datadirectory\" في تهيئتك.",
     "Your data directory is invalid." : "دليل بياناتك data directory غير صحيح.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "تأكد من وجود ملفٍ باسم \".ocdata\" في جذر دليل البيانات data directory.",
+    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "تأكّد من وجود ملف باسم \"%1$s\" في جذر دليل البيانات. وهو يجب أن يحتوى على: \"%2$s\"",
     "Action \"%s\" not supported or implemented." : "الإجراء \"%s\" غيرُ مدعومٍ أو غيرً مُطبّقٍ.",
     "Authentication failed, wrong token or provider ID given" : "فشلت المصادقة بسبب خطأ في الرمز token أو في رقم المُزوّد provider ID المُعطى.",
-    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "بارامترات لازمة لإكمال الطلب مفقودةٌ. و البارامترات هي: \"%s\"",
+    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "المعاملات المطلوبة لإكمال الطلب مفقودةٌ. المعاملات المطلوبة هي: \"%s\"",
     "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : " المُعّرف \"%1$s\" مٌستخدمٌ سلفاُ من مُزوّد اتحاد سحابي cloud fereration provider \"%2$s\"",
     "Cloud Federation Provider with ID: \"%s\" does not exist." : "لا يوجد مُزوّد اتحاد سحابي Cloud Federation Provider بهذا الاسم: \"%s\" .",
     "Could not obtain lock type %d on \"%s\"." : "تعذر الحصول على نوع القفل%d على \"%s\".",
@@ -262,38 +305,122 @@ OC.L10N.register(
     "Storage connection error. %s" : "خطأ في اتصال التخزين. %s ",
     "Storage is temporarily not available" : "وحدة التخزين غير متوفرة",
     "Storage connection timeout. %s" : "انتهت مهلة الاتصال بالتخزين. %s",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "للسماح بتشغيل هذا الفحص، عليك التأكد من أن خادم الويب الخاص بك يمكنه الاتصال بنفسه. لذلك، يجب أن يكون قادراً على حل المشكلة والاتصال بواحد على الأقل من \"النطاقات_الموثوقة\" أو \"overwrite.cli.url\". قد يكون هذا الفشل نتيجة لعدم تطابق DNS من جانب الخادم أو قاعدة صادرة لجدار الحماية.",
+    "Transcribe audio" : "تحويل الكلام لنص",
+    "Transcribe the things said in an audio" : "تحويل الكلام المحكي في المقطع الصوتي إلى نص",
+    "Audio input" : "المدخلات الصوتية",
+    "The audio to transcribe" : "الكلام المطلوب تحويله إلى نص",
+    "Transcription" : "تحويل الكلام لنص",
+    "The transcribed text" : "النص المُولّد من الكلام",
+    "Context write" : "كتابة السياق",
+    "Writes text in a given style based on the provided source material." : "يكتُب النص أسلوب معين بناءً على المادة المصدرية المتوفرة",
+    "Writing style" : "أسلُوب الكتابة",
+    "Demonstrate a writing style that you would like to immitate" : "قدّم نموذجاً لأسلوب الكتابة الذي ترغب في محاكاته",
+    "Source material" : "مصدر المواد",
+    "The content that would like to be rewritten in the new writing style" : "النص الذي ترغب في إعادة صياعته بأسلوب الكتابة الجديد",
+    "Generated text" : "النص المُولَّد",
+    "The generated text with content from the source material in the given style" : "النص المُولَّد مع محتوى من المادة الأصلية مكتوبة بالأسلوب المطلوب",
+    "Emoji generator" : "مُولِّد إيموجي",
+    "Takes text and generates a representative emoji for it." : "يقبل نصاً ثم يقوم بتوليد إيموجي مُعبِّر بناءً عليه.",
+    "The text to generate an emoji for" : "نص لتوليد إيموجي عن",
+    "Generated emoji" : "الإيموجي المُولَّد",
+    "The generated emoji based on the input text" : "الإيموجي المُولَّد بناءً على النص المُدخَل",
+    "Generate image" : "توليد صورة",
+    "Generate an image from a text prompt" : "توليد إيموجي من طلب نصّي",
+    "Prompt" : "المُطالبة prompt",
+    "Describe the image you want to generate" : "صِف الصورة التي ترغب في توليدها",
+    "Number of images" : "عدد الصِّوَر",
+    "How many images to generate" : "كم صورة سيتم توليدها",
+    "Output images" : "الصِّوَر الناتجة",
+    "The generated images" : "الصِّوَر المُولَّدة",
+    "Free text to text prompt" : "نص حر إلى نص طلب",
+    "Runs an arbitrary prompt through a language model that returns a reply" : "تشغيل مطالبة مفتوحة من خلال نموذج لغوي يجيب بالرّدّ",
+    "Describe a task that you want the assistant to do or ask a question" : "صِف المهمة التي تطلب العون لإنجازها أو اسأل سؤالاً",
+    "Generated reply" : "الرَّدّ المُولَّد",
+    "The generated text from the assistant" : "النص المُولَّد من قِبَل المُساعِد",
+    "Chat" : "دردشة",
+    "Chat with the assistant" : "دردشة مع المُساعِد",
+    "System prompt" : "مَحَثُّ النظام",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "تعريف القواعد و الافتراضات التي يجب على المساعد اتِّباعها خلال المحادثة.",
+    "Chat message" : "رسالة دردشة",
+    "Chat history" : "تاريخ الدردشة",
+    "The history of chat messages before the current message, starting with a message by the user" : "تاريخ رسائل الدردشة ما قبل الرسالة الحالية بدءاً برسالة من المستخدِم",
+    "Response message" : "رسالة الرّدّ",
+    "The generated response as part of the conversation" : "الرَّدّ المُولّد كجزء من المحادثة",
+    "Formalize text" : "إضفاء الطابع الرسمي على النّصّ",
+    "Takes a text and makes it sound more formal" : "يأخذ النص و يجعله يبدو أكثر رسميّةً",
+    "Write a text that you want the assistant to formalize" : "أكتُب النّصّ الذي ترغب من المساعد أن يجعله رسميّاً",
+    "Formalized text" : "نصٌ ذو طابع رسمي",
+    "The formalized text" : "النّصّ ذو الطابع الرسمي",
+    "Generate a headline" : "توليد عنوان",
+    "Generates a possible headline for a text." : "يقوم بتوليد عنوان مناسب للنص.",
+    "Original text" : "النص الأصلي",
+    "The original text to generate a headline for" : "النص الأصلي المطلوب توليد عنوانٍ له",
+    "The generated headline" : "العنوان الذي تم توليده",
+    "Reformulate text" : "إعادة صياغة النص",
+    "Takes a text and reformulates it" : "تأخذ النص و تضفي عليه طابعاً رسميّاً",
+    "Write a text that you want the assistant to reformulate" : "أكتُب النص الذي ترغب من المساعد أن يعيد صياغته",
+    "Reformulated text" : "نصٌّ معادةٌ صياغته",
+    "The reformulated text, written by the assistant" : "النّصّ مُعاد الصياغة من قِبَل المُساعِد",
+    "Simplify text" : "تبسيط النّصّ",
+    "Takes a text and simplifies it" : "تأخذ نصّاً و تُبسِّط صياغته",
+    "Write a text that you want the assistant to simplify" : "أكتب النص الذي ترغب من المساعد أن يُبسِّط صياغته",
+    "Simplified text" : "نص مُبسَّط الصياغة",
+    "The simplified text" : "النص المُبسَّط",
+    "Summarize" : "تلخيص",
+    "Summarizes a text" : "يٌلخِّص نصّاً",
+    "The original text to summarize" : "النص الأصلي المطلوب تلخيصه",
+    "Summary" : "مُلخَّص",
+    "The generated summary" : "الملخص المُولَّد",
+    "Extract topics" : "إستخلاص الموضوعات",
+    "Extracts topics from a text and outputs them separated by commas" : "يستخلص المواضيع من النص و يقوم بإخراجها مفصولاً بينها بفواصل",
+    "The original text to extract topics from" : "النص الأصلي المطوب استخلاص المواضيع منه",
+    "Topics" : "المواضيع",
+    "The list of extracted topics" : "قائمة المواضيع المستخلصة",
+    "Translate" : "ترجِم",
+    "Translate text from one language to another" : "ترجمة النص من لغة لأخرى",
+    "Origin text" : "النص الأصلي",
+    "The text to translate" : "النص المطلوب ترجمته",
+    "Origin language" : "اللغة الأصل",
+    "The language of the origin text" : "لغة النص الأصلي",
+    "Target language" : "اللغة المطلوبة",
+    "The desired language to translate the origin text in" : "اللغة المطلوب ترجمة النص إليها",
+    "Result" : "النتيجة",
+    "The translated text" : "النص المترجم",
     "Free prompt" : "مَحَثْ prompt مجاني",
     "Runs an arbitrary prompt through the language model." : "يقوم بتشغيل مَحَث عشوائي arbitrary prompt من خلال نموذج اللغة language model.",
     "Generate headline" : "توليد العنوان",
-    "Generates a possible headline for a text." : "يقوم بتوليد عنوان مناسب للنص.",
-    "Summarize" : "تلخيص",
     "Summarizes text by reducing its length without losing key information." : "يُلَخِّص النص بتقليل طوله دون فقدان المعنى.",
-    "Extract topics" : "إستخلاص الموضوعات",
     "Extracts topics from a text and outputs them separated by commas." : "يستخلص المواضيع من النص و إخراجها مفصولة بفواصل.",
-    "404" : "لم يتم العثور على الصفحة خطأ عدد 404",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "المستخدم الداخل يجب أن يكون مُشرفاً admin، أو مُشرفاً فرعيّاً sub admin، أو يحمل صلاحياتٍ خاصّةٍ للوصول إلى هذه الإعدادات.",
-    "Logged in user must be an admin or sub admin" : "المستخدم الداخل يجب أن يكون مُشرفاً admin، أو مُشرفاً فرعيّاً sub admin.",
-    "Logged in user must be an admin" : "المستخدم الداخل يجب أن يكون مُشرفاً admin.",
+    "Education Edition" : "الإصدار التعليمي",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "المستخدم المسجل دخوله يجب أن يكون مدير admin، أو مدير فرعي sub admin، أو يحمل صلاحياتٍ خاصّةٍ للوصول إلى هذه الإعدادات.",
+    "Logged in user must be an admin or sub admin" : "المستخدم المسجل دخوله يجب أن يكون مدير admin، أو مدير فرعي sub",
+    "Logged in user must be an admin" : "المستخدم المسجل دخوله يجب أن يكون مدير admin.",
+    "File name is a reserved word" : "اسم الملف كلمة محجوزة",
+    "File name contains at least one invalid character" : "اسم الملف به ، على الأقل ، حرف غير صالح",
+    "File name is too long" : "اسم الملف طويل جداً",
     "Help" : "المساعدة",
-    "Unknown user" : "المستخدم غير معروف",
+    "Users" : "المستخدمين",
+    "Unknown user" : "المستخدم مجهول",
     "Enter the database username and name for %s" : "أدخل اسم المستخدم و اسم قاعدة البيانات %s",
     "Enter the database username for %s" : "أدخل اسم المستخدم لقاعدة البيانات لـ %s",
     "MySQL username and/or password not valid" : "اسم المستخدم لقاعدة البيانات MySQL و/أو كلمة المرور غير صحيحة",
     "Oracle username and/or password not valid" : "اسم المستخدم  و/أو  كلمة المرور لنظام Oracle غير صحيح",
     "PostgreSQL username and/or password not valid" : "اسم المستخدم / أو كلمة المرور الخاصة بـPostgreSQL غير صحيحة",
-    "Set an admin username." : "اعداد اسم مستخدم المشرف",
+    "Set an admin username." : "اعداد اسم مستخدم المدير",
     "Sharing %s failed, because this item is already shared with user %s" : "المشاركة %sلم تتم لأن هذا العنصر سبقت مشاركته سلفاً مع المستخدم %s",
     "The username is already being used" : "اسم المستخدم قيد الاستخدام بالفعل",
     "Could not create user" : "لا يمكن إنشاء المستخدم",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "الحروف التالية فقط مسموحٌ بها في اسم المستخدِم: \"a-z\"و \"A-Z\"و \"0-9\" و الفراغ و  \"_.@-'\"",
     "A valid username must be provided" : "يجب ادخال اسم مستخدم صحيح",
-    "Username contains whitespace at the beginning or at the end" : "إنّ إسم المستخدم يحتوي على مسافة بيضاء سواءا في البداية أو النهاية",
+    "Username contains whitespace at the beginning or at the end" : "إنّ اسم المستخدم يحتوي على مسافة بيضاء سواءا في البداية أو النهاية",
     "Username must not consist of dots only" : "اسم المستخدم يجب ألاّ يتكون من نقاطٍ dots فقط",
     "Username is invalid because files already exist for this user" : "اسم المستخدم غير صحيحٍ لأن هنالك ملفات موجودة سلفاً لهذا المستخدم",
-    "User disabled" : "المستخدم معطّل",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 مطلوبة.",
-    "Please upgrade your database version." : "رجاءً، قم بترقية إصدار قاعدة بياناتك.",
+    "User disabled" : "تم تعطيل المستخدم",
+    "File is currently busy, please try again later" : "إنّ الملف مشغول الآمن، يرجى إعادة المحاولة لاحقًا",
+    "Cannot download file" : "لا يمكن تنزيل الملف",
     "Your data directory is readable by other users." : "دليل بياناتك data directory يُمكن قراءته من مستخدمين آخرين.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "الرجاء تغيير الصلاحيات إلى 0770 حتى لا يتمكن المستخدمون الآخرون من عرض محتويات المجلد."
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "الرجاء تغيير الصلاحيات إلى 0770 حتى لا يتمكن المستخدمون الآخرون من عرض محتويات المجلد.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "تأكد من وجود ملفٍ باسم \".ocdata\" في جذر دليل البيانات data directory."
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
