@@ -18,7 +18,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s 및 %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s 및 %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s 및 %5$s",
-    "Education Edition" : "교육용 에디션",
     "Enterprise bundle" : "엔터프라이즈 번들",
     "Groupware bundle" : "그룹웨어 번들",
     "Hub bundle" : "Hub 번들",
@@ -78,14 +77,12 @@ OC.L10N.register(
     "seconds ago" : "초 전",
     "Empty file" : "빈 파일",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "ID: %s인 모듈이 존재하지 않습니다. 앱 설정에서 확인하거나 시스템 관리자에게 연락하십시오.",
+    "Dot files are not allowed" : "점으로 시작하는 파일은 허용되지 않음",
     "File already exists" : "파일이 이미 있습니다.",
     "Invalid path" : "잘못된 경로",
     "Failed to create file from template" : "템플릿으로 새 파일을 만들 수 없음",
     "Templates" : "템플릿",
-    "File name is a reserved word" : "파일 이름이 예약된 단어임",
-    "File name contains at least one invalid character" : "파일 이름에 잘못된 글자가 한 자 이상 있음",
-    "File name is too long" : "파일 이름이 너무 김",
-    "Dot files are not allowed" : "점으로 시작하는 파일은 허용되지 않음",
+    "Filename contains at least one invalid character" : "파일 이름에 잘못된 글자가 한 자 이상 있음",
     "Empty filename is not allowed" : "파일 이름을 비워 둘 수 없음",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "appinfo 파일을 읽을 수 없어서 앱 \"%s\"을(를) 설치할 수 없습니다.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "이 서버 버전과 호환되지 않아서 앱 \"%s\"을(를) 설치할 수 없습니다",
@@ -97,7 +94,7 @@ OC.L10N.register(
     "Administration settings" : "관리자 설정",
     "Settings" : "설정",
     "Log out" : "로그아웃",
-    "Users" : "사용자",
+    "Accounts" : "계정",
     "Email" : "이메일",
     "Mail %s" : "%s에게 메일 보내기",
     "Fediverse" : "Fediverse",
@@ -130,11 +127,15 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "공유 백엔드 %s에서 OCP\\Share_Backend 인터페이스를 구현해야 함",
     "Sharing backend %s not found" : "공유 백엔드 %s을(를) 찾을 수 없음",
     "Sharing backend for %s not found" : "%s의 공유 백엔드를 찾을 수 없음",
+    "%1$s shared »%2$s« with you" : "%1$s 님이 »%2$s« 항목을 공유했습니다",
+    "%1$s shared »%2$s« with you." : "%1$s 님이 »%2$s« 항목을 공유했습니다",
+    "Click the button below to open it." : "아래 단추를 눌러서 열 수 있습니다.",
+    "Open »%s«" : "%s 열기",
+    "%1$s via %2$s" : "%1$s(%2$s 경유)",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s님이 %2$s을(를) 당신과 공유하며, 다음을 추가하고자 함:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s님이 %2$s을(를) 당신과 공유하며 다음을 추가하고자 함",
     "»%s« added a note to a file shared with you" : "%s님이 당신과 공유한 파일에 메모를 추가함",
-    "Open »%s«" : "%s 열기",
-    "%1$s via %2$s" : "%1$s(%2$s 경유)",
+    "Unknown share type" : "알 수 없는 공유 형식",
     "You are not allowed to share %s" : "%s을(를) 공유할 수 있는 권한이 없습니다",
     "Cannot increase permissions of %s" : "%s의 권한을 늘릴 수 없습니다.",
     "Files cannot be shared with delete permissions" : "파일을 삭제 권한으로 공유할 수 없습니다",
@@ -143,9 +144,6 @@ OC.L10N.register(
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["만료 날짜는 최대 %s일까지 설정할 수 있습니다"],
     "Sharing is only allowed with group members" : "같은 그룹 사용자에게만 공유할 수 있습니다",
     "Sharing %s failed, because this item is already shared with the account %s" : "%s을(를) 공유할 수 없습니다. 이 항목을 이미 %s 계정과 공유하고 있습니다",
-    "%1$s shared »%2$s« with you" : "%1$s 님이 »%2$s« 항목을 공유했습니다",
-    "%1$s shared »%2$s« with you." : "%1$s 님이 »%2$s« 항목을 공유했습니다",
-    "Click the button below to open it." : "아래 단추를 눌러서 열 수 있습니다.",
     "The requested share does not exist anymore" : "요청한 공유가 더 이상 존재하지 않습니다",
     "The requested share comes from a disabled user" : "요청한 공유가 비활성화된 사용자로부터 수신되었습니다",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "사용자 수 제한에 도달하여 사용자를 만들 수 없습니다. 더 자세한 정보는 알림을 참조하십시오.",
@@ -201,8 +199,6 @@ OC.L10N.register(
     "Login canceled by app" : "앱에서 로그인 취소함",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "앱 \"%1$s\"이(가) 다음 의존성을 만족하지 않아 설치될 수 없습니다: %2$s",
     "a safe home for all your data" : "내 모든 데이터의 안전한 저장소",
-    "File is currently busy, please try again later" : "파일이 현재 사용 중, 나중에 다시 시도하십시오",
-    "Cannot download file" : "파일을 다운로드할 수 없음",
     "Application is not enabled" : "앱이 활성화되지 않았습니다",
     "Authentication error" : "인증 오류",
     "Token expired. Please reload page." : "토큰이 만료되었습니다. 페이지를 새로 고치십시오.",
@@ -233,7 +229,6 @@ OC.L10N.register(
     "Your data directory must be an absolute path." : "데이터 디렉토리는 절대경로여야 합니다.",
     "Check the value of \"datadirectory\" in your configuration." : "설정에서 \"datadirectory\"의 값을 확인하십시오.",
     "Your data directory is invalid." : "데이터 디렉토리가 올바르지 않습니다.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "데이터 디렉터리의 최상위 디렉터리에 \".ocdata\" 파일이 있는지 확인하십시오.",
     "Action \"%s\" not supported or implemented." : "동작 \"%s\"을(를) 지원하지 않거나 사용할 수 없습니다. ",
     "Authentication failed, wrong token or provider ID given" : "인증이 실패하였습니다. 토큰이나 프로바이더 ID가 틀렸습니다.",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "요청을 완료하기 위한 매개변수가 누락되었습니다. 누락된 매개변수: \"%s\"",
@@ -245,16 +240,32 @@ OC.L10N.register(
     "Storage connection error. %s" : "저장소 연결 오류입니다. %s",
     "Storage is temporarily not available" : "저장소를 임시로 사용할 수 없음",
     "Storage connection timeout. %s" : "저장소 연결 시간이 초과되었습니다. %s",
-    "Generate headline" : "헤드라인 생성",
+    "Audio input" : "음성 입력",
+    "Context write" : "컨텍스트 쓰기",
+    "Writes text in a given style based on the provided source material." : "제공된 소스 자료를 기반으로 특정 스타일로 텍스트를 작성합니다.",
+    "Writing style" : "작문 스타일",
+    "Source material" : "소스 자료",
+    "Generate image" : "이미지 생성",
+    "Prompt" : "프롬프트",
+    "Chat" : "대화",
     "Generates a possible headline for a text." : "내용에 대한 헤드라인을 생성하십시오.",
     "Summarize" : "요약",
-    "Summarizes text by reducing its length without losing key information." : "중요 정보로 내용을 축약하십시오.",
+    "Summary" : "요약",
     "Extract topics" : "주제 추출",
+    "Translate" : "번역:",
+    "Result" : "결과",
+    "Generate headline" : "헤드라인 생성",
+    "Summarizes text by reducing its length without losing key information." : "중요 정보로 내용을 축약하십시오.",
     "Extracts topics from a text and outputs them separated by commas." : "내용에서 주요 주제를 추출하고 쉼표로 이를 구분하십시오.",
+    "Education Edition" : "교육용 에디션",
     "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "로그인된 사용자가 관리자, 부 관리자, 또는 이 설정에 접근할 수 있는 권한을 부여받은 사용자일 것입니다.",
     "Logged in user must be an admin or sub admin" : "로그인한 사용자는 관리자 또는 부 관리자여야 합니다.",
     "Logged in user must be an admin" : "로그인한 사용자는 관리자여야 합니다.",
+    "File name is a reserved word" : "파일 이름이 예약된 단어임",
+    "File name contains at least one invalid character" : "파일 이름에 잘못된 글자가 한 자 이상 있음",
+    "File name is too long" : "파일 이름이 너무 김",
     "Help" : "도움말",
+    "Users" : "사용자",
     "Unknown user" : "알려지지 않은 사용자",
     "Enter the database username and name for %s" : "%s에 대한 데이터베이스 사용자 이름과 이름을 입력하십시오",
     "Enter the database username for %s" : "%s에 대한 데이터베이스 사용자 이름을 입력하십시오",
@@ -271,9 +282,10 @@ OC.L10N.register(
     "Username must not consist of dots only" : "사용자 이름에 마침표만 있으면 안 됩니다",
     "Username is invalid because files already exist for this user" : "무효한 사용자이름. 이미 존재함",
     "User disabled" : "사용자 비활성화됨",
-    "PostgreSQL >= 9 required." : "PostgreSQL 버전 9 이상이 필요합니다",
-    "Please upgrade your database version." : "데이터베이스 버전을 업그레이드 하십시오",
+    "File is currently busy, please try again later" : "파일이 현재 사용 중, 나중에 다시 시도하십시오",
+    "Cannot download file" : "파일을 다운로드할 수 없음",
     "Your data directory is readable by other users." : "현재 데이터 디렉토리를 다른 사람이 읽을 수 있습니다.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "권한을 0770으로 변경하여 다른 사용자가 읽을 수 없도록 하십시오."
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "권한을 0770으로 변경하여 다른 사용자가 읽을 수 없도록 하십시오.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "데이터 디렉터리의 최상위 디렉터리에 \".ocdata\" 파일이 있는지 확인하십시오."
 },
 "nplurals=1; plural=0;");
