@@ -19,7 +19,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s și %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s și %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s și %5$s",
-    "Education Edition" : "Ediția pentru educație",
     "Enterprise bundle" : "Pachetul enterprise",
     "Groupware bundle" : "Pachetul Groupware",
     "Hub bundle" : "Pachetul central",
@@ -76,14 +75,12 @@ OC.L10N.register(
     "seconds ago" : "secunde în urmă",
     "Empty file" : "Fișier gol",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulul cu ID: %s nu există. Activați-l din setările aplicației sau contactați administratorul.",
+    "Dot files are not allowed" : "Fișierele care încep cu caracterul punct nu sunt permise",
     "File already exists" : "Fișierul există deja",
     "Invalid path" : "Cale invalidă",
     "Failed to create file from template" : "Eroare la crearea fișierului pe baza șablonului",
     "Templates" : "Șabloane",
-    "File name is a reserved word" : "Numele fișierului este un cuvânt rezervat",
-    "File name contains at least one invalid character" : "Numele fișierului conține cel puțin un caracter invalid",
-    "File name is too long" : "Numele fișierului este prea lung",
-    "Dot files are not allowed" : "Fișierele care încep cu caracterul punct nu sunt permise",
+    "Filename contains at least one invalid character" : "Numele fișierului conține cel puțin un caracter invalid",
     "Empty filename is not allowed" : "Nu este permis fișier fără nume",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplicația \"%s\" nu poate fi instalată deoarece fișierul appinfo nu poate fi citit.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplicația \"%s\" nu poate fi instalată deoarece nu este compatibilă cu versiunea serverului.",
@@ -95,7 +92,7 @@ OC.L10N.register(
     "Administration settings" : "Setări de administrare",
     "Settings" : "Setări",
     "Log out" : "Ieșire",
-    "Users" : "Utilizatori",
+    "Accounts" : "Conturi",
     "Email" : "E-mail",
     "View %s on the fediverse" : "Vedeți %s pe fediverse",
     "Phone" : "Telefon",
@@ -125,11 +122,15 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend-ul de partajare %s trebuie să implementeze interfața OCP\\Share_Backend",
     "Sharing backend %s not found" : "Backend-ul de partajare %s nu există",
     "Sharing backend for %s not found" : "Backend-ul de partajare pentru %s nu a fost găsit",
+    "%1$s shared »%2$s« with you" : "%1$s a partajat »%2$s« cu tine",
+    "%1$s shared »%2$s« with you." : "%1$sa partajat »%2$s« cu tine.",
+    "Click the button below to open it." : "Apasă pe butonul de jos pentru a deschide.",
+    "Open »%s«" : "Deschide »%s«",
+    "%1$s via %2$s" : "%1$sprin %2$s",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s a partajat »%2$s« cu tine și vrea să adauge:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s a partajat »%2$s« cu tine și vrea să adauge",
     "»%s« added a note to a file shared with you" : "%s« a adaugat un comentariu la un fișier partajat cu tine",
-    "Open »%s«" : "Deschide »%s«",
-    "%1$s via %2$s" : "%1$sprin %2$s",
+    "Unknown share type" : "Tip necunoscut de partajare",
     "You are not allowed to share %s" : "Nu există permisiunea de partajare %s",
     "Cannot increase permissions of %s" : "Nu se pot extinde permisiunile pentru %s",
     "Files cannot be shared with delete permissions" : "Fișierele nu pot fi partajate cu permisiunea de ștergere",
@@ -137,9 +138,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Data expirării este în trecut",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Data expirării nu poate fi mai mult de %n zi în viitor","Data expirării nu poate fi mai mult de %n zile în viitor","Data expirării nu poate fi mai mult de %n zile în viitor"],
     "Sharing is only allowed with group members" : "Partajarea este permisă doar cu membrii grupului",
-    "%1$s shared »%2$s« with you" : "%1$s a partajat »%2$s« cu tine",
-    "%1$s shared »%2$s« with you." : "%1$sa partajat »%2$s« cu tine.",
-    "Click the button below to open it." : "Apasă pe butonul de jos pentru a deschide.",
     "The requested share does not exist anymore" : "Partajarea solicitată nu mai există",
     "The requested share comes from a disabled user" : "Partajarea solicitată provine de la un utilizator dezactivat",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Utilizatorul nu a fost creat deoarece s-a atins limita acestui număr. Verificați notificările pentru a afla mai mult.",
@@ -193,8 +191,6 @@ OC.L10N.register(
     "Login canceled by app" : "Autentificare anulată de aplicație",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplicația \"%1$s\" nu poate fi instalată deoarece următoarele dependențe nu sunt satisfăcute: %2$s",
     "a safe home for all your data" : "o casă sigură pentru toate datele dumneavoastră",
-    "File is currently busy, please try again later" : "Fișierul este blocat momentan, încercați din nou mai târziu",
-    "Cannot download file" : "Fișierul nu se poate descărca",
     "Application is not enabled" : "Aplicația nu este activată",
     "Authentication error" : "Eroare la autentificare",
     "Token expired. Please reload page." : "Token expirat. Te rugăm să reîncarci pagina.",
@@ -225,7 +221,6 @@ OC.L10N.register(
     "Your data directory must be an absolute path." : "Directorul de date trebuie să fie o cale absolută.",
     "Check the value of \"datadirectory\" in your configuration." : "Verificați valoarea \"datadirectory\" în configurație.",
     "Your data directory is invalid." : "Directorul de date este invalid.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asigurați-vă că fișierul \".ocdata\" există în rădăcina directorului de date.",
     "Action \"%s\" not supported or implemented." : "Acțiunea \"%s\" nu este suportată sau implementată.",
     "Authentication failed, wrong token or provider ID given" : "Autentificare eșuată, token greșit sau ID provider eronat",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parametri lipsă pentru îndeplinirea solicitării. Parametrii lipsă: \"%s\"",
@@ -237,18 +232,25 @@ OC.L10N.register(
     "Storage connection error. %s" : "Eroare conexiune cu spațiul de stocare. %s",
     "Storage is temporarily not available" : "Spațiu de stocare este indisponibil temporar",
     "Storage connection timeout. %s" : "Timeout la conexiunea cu spațiul de stocare. %s",
+    "Generates a possible headline for a text." : "Generează un posibil titlu pentru text",
+    "Summarize" : "Rezumă",
+    "Summary" : "Rezumat",
+    "Extract topics" : "Extrage subiecte",
+    "Translate" : "Tradu",
     "Free prompt" : "Eliberează prompt-ul",
     "Runs an arbitrary prompt through the language model." : "Rulează un prompt arbitrar prin modelul lingvistic.",
     "Generate headline" : "Generează titlu",
-    "Generates a possible headline for a text." : "Generează un posibil titlu pentru text",
-    "Summarize" : "Rezumă",
     "Summarizes text by reducing its length without losing key information." : "Rezumă textul prin reducerea lungimii acestuia, fără a pierde informațiile cheie.",
-    "Extract topics" : "Extrage subiecte",
     "Extracts topics from a text and outputs them separated by commas." : "Extrage subiecte din text și le furnizează separate prin virgulă.",
+    "Education Edition" : "Ediția pentru educație",
     "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Utilizatorul trebuie să fie administrator, sub-administrator sau să aibă permisiunea specială de a accesa această setare",
     "Logged in user must be an admin or sub admin" : "Utilizatorul trebuie să fie administrator sau sub-administrator",
     "Logged in user must be an admin" : "Utilizatorul trebuie să fie administrator",
+    "File name is a reserved word" : "Numele fișierului este un cuvânt rezervat",
+    "File name contains at least one invalid character" : "Numele fișierului conține cel puțin un caracter invalid",
+    "File name is too long" : "Numele fișierului este prea lung",
     "Help" : "Ajutor",
+    "Users" : "Utilizatori",
     "Unknown user" : "Utilizator necunoscut",
     "Enter the database username and name for %s" : "Introduceți utilizatorul pentru baza de date și numele pentru %s",
     "Enter the database username for %s" : "Introduceți utilizatorul pentru %s",
@@ -265,9 +267,10 @@ OC.L10N.register(
     "Username must not consist of dots only" : "Numele utilizatorului nu poate conține numai puncte",
     "Username is invalid because files already exist for this user" : "Numele utilizatorului este invalid deoarece există deja fișiere pentru acesta",
     "User disabled" : "Utilizator dezactivat",
-    "PostgreSQL >= 9 required." : "Este necesar PostgreSQL >= 9 .",
-    "Please upgrade your database version." : "Faceți upgrade la versiunea bazei de date.",
+    "File is currently busy, please try again later" : "Fișierul este blocat momentan, încercați din nou mai târziu",
+    "Cannot download file" : "Fișierul nu se poate descărca",
     "Your data directory is readable by other users." : "Directorul de date este accesibil altor utilizatori.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Setați permisiunea 0770 astfel ca directorul să nu poată fi parcurs de alți utilizatori."
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Setați permisiunea 0770 astfel ca directorul să nu poată fi parcurs de alți utilizatori.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asigurați-vă că fișierul \".ocdata\" există în rădăcina directorului de date."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
